# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
from google.type import localized_text_pb2  # type: ignore
import proto  # type: ignore

from google.maps.places_v1.types import attribution

__protobuf__ = proto.module(
    package="google.maps.places.v1",
    manifest={
        "Review",
    },
)


class Review(proto.Message):
    r"""Information about a review of a place.

    Attributes:
        name (str):
            A reference representing this place review which may be used
            to look up this place review again (also called the API
            "resource" name: ``places/{place_id}/reviews/{review}``).
        relative_publish_time_description (str):
            A string of formatted recent time, expressing
            the review time relative to the current time in
            a form appropriate for the language and country.
        text (google.type.localized_text_pb2.LocalizedText):
            The localized text of the review.
        original_text (google.type.localized_text_pb2.LocalizedText):
            The review text in its original language.
        rating (float):
            A number between 1.0 and 5.0, also called the
            number of stars.
        author_attribution (google.maps.places_v1.types.AuthorAttribution):
            This review's author.
        publish_time (google.protobuf.timestamp_pb2.Timestamp):
            Timestamp for the review.
        flag_content_uri (str):
            A link where users can flag a problem with
            the review.
        google_maps_uri (str):
            A link to show the review on Google Maps.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    relative_publish_time_description: str = proto.Field(
        proto.STRING,
        number=2,
    )
    text: localized_text_pb2.LocalizedText = proto.Field(
        proto.MESSAGE,
        number=9,
        message=localized_text_pb2.LocalizedText,
    )
    original_text: localized_text_pb2.LocalizedText = proto.Field(
        proto.MESSAGE,
        number=12,
        message=localized_text_pb2.LocalizedText,
    )
    rating: float = proto.Field(
        proto.DOUBLE,
        number=7,
    )
    author_attribution: attribution.AuthorAttribution = proto.Field(
        proto.MESSAGE,
        number=13,
        message=attribution.AuthorAttribution,
    )
    publish_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=14,
        message=timestamp_pb2.Timestamp,
    )
    flag_content_uri: str = proto.Field(
        proto.STRING,
        number=15,
    )
    google_maps_uri: str = proto.Field(
        proto.STRING,
        number=16,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.maps.places.v1",
    manifest={
        "TravelMode",
    },
)


class TravelMode(proto.Enum):
    r"""Travel mode options. These options map to what `Routes API
    offers <https://developers.google.com/maps/documentation/routes/reference/rest/v2/RouteTravelMode>`__.

    Values:
        TRAVEL_MODE_UNSPECIFIED (0):
            No travel mode specified. Defaults to ``DRIVE``.
        DRIVE (1):
            Travel by passenger car.
        BICYCLE (2):
            Travel by bicycle. Not supported with
            ``search_along_route_parameters``.
        WALK (3):
            Travel by walking. Not supported with
            ``search_along_route_parameters``.
        TWO_WHEELER (4):
            Motorized two wheeled vehicles of all kinds such as scooters
            and motorcycles. Note that this is distinct from the
            ``BICYCLE`` travel mode which covers human-powered
            transport. Not supported with
            ``search_along_route_parameters``. Only supported in those
            countries listed at `Countries and regions supported for
            two-wheeled
            vehicles <https://developers.google.com/maps/documentation/routes/coverage-two-wheeled>`__.
    """
    TRAVEL_MODE_UNSPECIFIED = 0
    DRIVE = 1
    BICYCLE = 2
    WALK = 3
    TWO_WHEELER = 4


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.type import money_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.maps.places.v1",
    manifest={
        "PriceRange",
    },
)


class PriceRange(proto.Message):
    r"""The price range associated with a Place. ``end_price`` could be
    unset, which indicates a range without upper bound (e.g. "More than
    $100").

    Attributes:
        start_price (google.type.money_pb2.Money):
            The low end of the price range (inclusive).
            Price should be at or above this amount.
        end_price (google.type.money_pb2.Money):
            The high end of the price range (exclusive).
            Price should be lower than this amount.
    """

    start_price: money_pb2.Money = proto.Field(
        proto.MESSAGE,
        number=1,
        message=money_pb2.Money,
    )
    end_price: money_pb2.Money = proto.Field(
        proto.MESSAGE,
        number=2,
        message=money_pb2.Money,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.maps.places_v1.types import photo
from google.maps.places_v1.types import review as gmp_review

__protobuf__ = proto.module(
    package="google.maps.places.v1",
    manifest={
        "ContextualContent",
    },
)


class ContextualContent(proto.Message):
    r"""Experimental: See
    https://developers.google.com/maps/documentation/places/web-service/experimental/places-generative
    for more details.

    Content that is contextual to the place query.

    Attributes:
        reviews (MutableSequence[google.maps.places_v1.types.Review]):
            List of reviews about this place, contexual
            to the place query.
        photos (MutableSequence[google.maps.places_v1.types.Photo]):
            Information (including references) about
            photos of this place, contexual to the place
            query.
        justifications (MutableSequence[google.maps.places_v1.types.ContextualContent.Justification]):
            Experimental: See
            https://developers.google.com/maps/documentation/places/web-service/experimental/places-generative
            for more details.

            Justifications for the place.
    """

    class Justification(proto.Message):
        r"""Experimental: See
        https://developers.google.com/maps/documentation/places/web-service/experimental/places-generative
        for more details.

        Justifications for the place. Justifications answers the
        question of why a place could interest an end user.

        This message has `oneof`_ fields (mutually exclusive fields).
        For each oneof, at most one member field can be set at the same time.
        Setting any member of the oneof automatically clears all other
        members.

        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            review_justification (google.maps.places_v1.types.ContextualContent.Justification.ReviewJustification):
                Experimental: See
                https://developers.google.com/maps/documentation/places/web-service/experimental/places-generative
                for more details.

                This field is a member of `oneof`_ ``justification``.
            business_availability_attributes_justification (google.maps.places_v1.types.ContextualContent.Justification.BusinessAvailabilityAttributesJustification):
                Experimental: See
                https://developers.google.com/maps/documentation/places/web-service/experimental/places-generative
                for more details.

                This field is a member of `oneof`_ ``justification``.
        """

        class ReviewJustification(proto.Message):
            r"""Experimental: See
            https://developers.google.com/maps/documentation/places/web-service/experimental/places-generative
            for more details.

            User review justifications. This highlights a section of the
            user review that would interest an end user. For instance, if
            the search query is "firewood pizza", the review justification
            highlights the text relevant to the search query.

            Attributes:
                highlighted_text (google.maps.places_v1.types.ContextualContent.Justification.ReviewJustification.HighlightedText):

                review (google.maps.places_v1.types.Review):
                    The review that the highlighted text is
                    generated from.
            """

            class HighlightedText(proto.Message):
                r"""The text highlighted by the justification. This is a subset
                of the review itself. The exact word to highlight is marked by
                the HighlightedTextRange. There could be several words in the
                text being highlighted.

                Attributes:
                    text (str):

                    highlighted_text_ranges (MutableSequence[google.maps.places_v1.types.ContextualContent.Justification.ReviewJustification.HighlightedText.HighlightedTextRange]):
                        The list of the ranges of the highlighted
                        text.
                """

                class HighlightedTextRange(proto.Message):
                    r"""The range of highlighted text.

                    Attributes:
                        start_index (int):

                        end_index (int):

                    """

                    start_index: int = proto.Field(
                        proto.INT32,
                        number=1,
                    )
                    end_index: int = proto.Field(
                        proto.INT32,
                        number=2,
                    )

                text: str = proto.Field(
                    proto.STRING,
                    number=1,
                )
                highlighted_text_ranges: MutableSequence[
                    "ContextualContent.Justification.ReviewJustification.HighlightedText.HighlightedTextRange"
                ] = proto.RepeatedField(
                    proto.MESSAGE,
                    number=2,
                    message="ContextualContent.Justification.ReviewJustification.HighlightedText.HighlightedTextRange",
                )

            highlighted_text: "ContextualContent.Justification.ReviewJustification.HighlightedText" = proto.Field(
                proto.MESSAGE,
                number=1,
                message="ContextualContent.Justification.ReviewJustification.HighlightedText",
            )
            review: gmp_review.Review = proto.Field(
                proto.MESSAGE,
                number=2,
                message=gmp_review.Review,
            )

        class BusinessAvailabilityAttributesJustification(proto.Message):
            r"""Experimental: See
            https://developers.google.com/maps/documentation/places/web-service/experimental/places-generative
            for more details.
            BusinessAvailabilityAttributes justifications. This shows some
            attributes a business has that could interest an end user.

            Attributes:
                takeout (bool):
                    If a place provides takeout.
                delivery (bool):
                    If a place provides delivery.
                dine_in (bool):
                    If a place provides dine-in.
            """

            takeout: bool = proto.Field(
                proto.BOOL,
                number=1,
            )
            delivery: bool = proto.Field(
                proto.BOOL,
                number=2,
            )
            dine_in: bool = proto.Field(
                proto.BOOL,
                number=3,
            )

        review_justification: "ContextualContent.Justification.ReviewJustification" = (
            proto.Field(
                proto.MESSAGE,
                number=1,
                oneof="justification",
                message="ContextualContent.Justification.ReviewJustification",
            )
        )
        business_availability_attributes_justification: "ContextualContent.Justification.BusinessAvailabilityAttributesJustification" = proto.Field(
            proto.MESSAGE,
            number=2,
            oneof="justification",
            message="ContextualContent.Justification.BusinessAvailabilityAttributesJustification",
        )

    reviews: MutableSequence[gmp_review.Review] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=gmp_review.Review,
    )
    photos: MutableSequence[photo.Photo] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message=photo.Photo,
    )
    justifications: MutableSequence[Justification] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message=Justification,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .address_descriptor import AddressDescriptor
from .attribution import AuthorAttribution
from .content_block import ContentBlock
from .contextual_content import ContextualContent
from .ev_charging import EVChargeOptions, EVConnectorType
from .fuel_options import FuelOptions
from .geometry import Circle
from .photo import Photo
from .place import Place, PriceLevel
from .places_service import (
    AutocompletePlacesRequest,
    AutocompletePlacesResponse,
    GetPhotoMediaRequest,
    GetPlaceRequest,
    PhotoMedia,
    RoutingParameters,
    SearchNearbyRequest,
    SearchNearbyResponse,
    SearchTextRequest,
    SearchTextResponse,
)
from .polyline import Polyline
from .price_range import PriceRange
from .reference import References
from .review import Review
from .route_modifiers import RouteModifiers
from .routing_preference import RoutingPreference
from .routing_summary import RoutingSummary
from .travel_mode import TravelMode

__all__ = (
    "AddressDescriptor",
    "AuthorAttribution",
    "ContentBlock",
    "ContextualContent",
    "EVChargeOptions",
    "EVConnectorType",
    "FuelOptions",
    "Circle",
    "Photo",
    "Place",
    "PriceLevel",
    "AutocompletePlacesRequest",
    "AutocompletePlacesResponse",
    "GetPhotoMediaRequest",
    "GetPlaceRequest",
    "PhotoMedia",
    "RoutingParameters",
    "SearchNearbyRequest",
    "SearchNearbyResponse",
    "SearchTextRequest",
    "SearchTextResponse",
    "Polyline",
    "PriceRange",
    "References",
    "Review",
    "RouteModifiers",
    "RoutingPreference",
    "RoutingSummary",
    "TravelMode",
)



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.maps.places.v1",
    manifest={
        "RouteModifiers",
    },
)


class RouteModifiers(proto.Message):
    r"""Encapsulates a set of optional conditions to satisfy when
    calculating the routes.

    Attributes:
        avoid_tolls (bool):
            Optional. When set to true, avoids toll roads where
            reasonable, giving preference to routes not containing toll
            roads. Applies only to the ``DRIVE`` and ``TWO_WHEELER``
            [``TravelMode``][google.maps.places.v1.TravelMode].
        avoid_highways (bool):
            Optional. When set to true, avoids highways where
            reasonable, giving preference to routes not containing
            highways. Applies only to the ``DRIVE`` and ``TWO_WHEELER``
            [``TravelMode``][google.maps.places.v1.TravelMode].
        avoid_ferries (bool):
            Optional. When set to true, avoids ferries where reasonable,
            giving preference to routes not containing ferries. Applies
            only to the ``DRIVE`` and ``TWO_WHEELER``
            [``TravelMode``][google.maps.places.v1.TravelMode].
        avoid_indoor (bool):
            Optional. When set to true, avoids navigating indoors where
            reasonable, giving preference to routes not containing
            indoor navigation. Applies only to the ``WALK``
            [``TravelMode``][google.maps.places.v1.TravelMode].
    """

    avoid_tolls: bool = proto.Field(
        proto.BOOL,
        number=1,
    )
    avoid_highways: bool = proto.Field(
        proto.BOOL,
        number=2,
    )
    avoid_ferries: bool = proto.Field(
        proto.BOOL,
        number=3,
    )
    avoid_indoor: bool = proto.Field(
        proto.BOOL,
        number=4,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.type import latlng_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.maps.places.v1",
    manifest={
        "Circle",
    },
)


class Circle(proto.Message):
    r"""Circle with a LatLng as center and radius.

    Attributes:
        center (google.type.latlng_pb2.LatLng):
            Required. Center latitude and longitude.

            The range of latitude must be within [-90.0, 90.0]. The
            range of the longitude must be within [-180.0, 180.0].
        radius (float):
            Required. Radius measured in meters. The radius must be
            within [0.0, 50000.0].
    """

    center: latlng_pb2.LatLng = proto.Field(
        proto.MESSAGE,
        number=1,
        message=latlng_pb2.LatLng,
    )
    radius: float = proto.Field(
        proto.DOUBLE,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.type import localized_text_pb2  # type: ignore
import proto  # type: ignore

from google.maps.places_v1.types import reference

__protobuf__ = proto.module(
    package="google.maps.places.v1",
    manifest={
        "ContentBlock",
    },
)


class ContentBlock(proto.Message):
    r"""A block of content that can be served individually.

    Attributes:
        topic (str):
            The topic of the content, for example
            "overview" or "restaurant".
        content (google.type.localized_text_pb2.LocalizedText):
            Content related to the topic.
        references (google.maps.places_v1.types.References):
            Experimental: See
            https://developers.google.com/maps/documentation/places/web-service/experimental/places-generative
            for more details.

            References that are related to this block of
            content.
    """

    topic: str = proto.Field(
        proto.STRING,
        number=1,
    )
    content: localized_text_pb2.LocalizedText = proto.Field(
        proto.MESSAGE,
        number=2,
        message=localized_text_pb2.LocalizedText,
    )
    references: reference.References = proto.Field(
        proto.MESSAGE,
        number=3,
        message=reference.References,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import duration_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.maps.places.v1",
    manifest={
        "RoutingSummary",
    },
)


class RoutingSummary(proto.Message):
    r"""The duration and distance from the routing origin to a place in the
    response, and a second leg from that place to the destination, if
    requested. **Note:** Adding ``routingSummaries`` in the field mask
    without also including either the ``routingParameters.origin``
    parameter or the
    ``searchAlongRouteParameters.polyline.encodedPolyline`` parameter in
    the request causes an error.

    Attributes:
        legs (MutableSequence[google.maps.places_v1.types.RoutingSummary.Leg]):
            The legs of the trip.

            When you calculate travel duration and distance from a set
            origin, ``legs`` contains a single leg containing the
            duration and distance from the origin to the destination.
            When you do a search along route, ``legs`` contains two
            legs: one from the origin to place, and one from the place
            to the destination.
        directions_uri (str):
            A link to show directions on Google Maps using the waypoints
            from the given routing summary. The route generated by this
            link is not guaranteed to be the same as the route used to
            generate the routing summary. The link uses information
            provided in the request, from fields including
            ``routingParameters`` and ``searchAlongRouteParameters``
            when applicable, to generate the directions link.
    """

    class Leg(proto.Message):
        r"""A leg is a single portion of a journey from one location to
        another.

        Attributes:
            duration (google.protobuf.duration_pb2.Duration):
                The time it takes to complete this leg of the
                trip.
            distance_meters (int):
                The distance of this leg of the trip.
        """

        duration: duration_pb2.Duration = proto.Field(
            proto.MESSAGE,
            number=1,
            message=duration_pb2.Duration,
        )
        distance_meters: int = proto.Field(
            proto.INT32,
            number=2,
        )

    legs: MutableSequence[Leg] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=Leg,
    )
    directions_uri: str = proto.Field(
        proto.STRING,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.maps.places.v1",
    manifest={
        "AuthorAttribution",
    },
)


class AuthorAttribution(proto.Message):
    r"""Information about the author of the UGC data. Used in
    [Photo][google.maps.places.v1.Photo], and
    [Review][google.maps.places.v1.Review].

    Attributes:
        display_name (str):
            Name of the author of the
            [Photo][google.maps.places.v1.Photo] or
            [Review][google.maps.places.v1.Review].
        uri (str):
            URI of the author of the
            [Photo][google.maps.places.v1.Photo] or
            [Review][google.maps.places.v1.Review].
        photo_uri (str):
            Profile photo URI of the author of the
            [Photo][google.maps.places.v1.Photo] or
            [Review][google.maps.places.v1.Review].
    """

    display_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    uri: str = proto.Field(
        proto.STRING,
        number=2,
    )
    photo_uri: str = proto.Field(
        proto.STRING,
        number=3,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.maps.places.v1",
    manifest={
        "EVConnectorType",
        "EVChargeOptions",
    },
)


class EVConnectorType(proto.Enum):
    r"""See
    http://ieeexplore.ieee.org/stamp/stamp.jsp?arnumber=6872107 for
    additional information/context on EV charging connector types.

    Values:
        EV_CONNECTOR_TYPE_UNSPECIFIED (0):
            Unspecified connector.
        EV_CONNECTOR_TYPE_OTHER (1):
            Other connector types.
        EV_CONNECTOR_TYPE_J1772 (2):
            J1772 type 1 connector.
        EV_CONNECTOR_TYPE_TYPE_2 (3):
            IEC 62196 type 2 connector. Often referred to
            as MENNEKES.
        EV_CONNECTOR_TYPE_CHADEMO (4):
            CHAdeMO type connector.
        EV_CONNECTOR_TYPE_CCS_COMBO_1 (5):
            Combined Charging System (AC and DC). Based
            on SAE.  Type-1 J-1772 connector
        EV_CONNECTOR_TYPE_CCS_COMBO_2 (6):
            Combined Charging System (AC and DC). Based
            on Type-2 Mennekes connector
        EV_CONNECTOR_TYPE_TESLA (7):
            The generic TESLA connector. This is NACS in
            the North America but can be non-NACS in other
            parts of the world (e.g. CCS Combo 2 (CCS2) or
            GB/T). This value is less representative of an
            actual connector type, and more represents the
            ability to charge a Tesla brand vehicle at a
            Tesla owned charging station.
        EV_CONNECTOR_TYPE_UNSPECIFIED_GB_T (8):
            GB/T type corresponds to the GB/T standard in China. This
            type covers all GB_T types.
        EV_CONNECTOR_TYPE_UNSPECIFIED_WALL_OUTLET (9):
            Unspecified wall outlet.
        EV_CONNECTOR_TYPE_NACS (10):
            The North American Charging System (NACS),
            standardized as SAE J3400.
    """
    EV_CONNECTOR_TYPE_UNSPECIFIED = 0
    EV_CONNECTOR_TYPE_OTHER = 1
    EV_CONNECTOR_TYPE_J1772 = 2
    EV_CONNECTOR_TYPE_TYPE_2 = 3
    EV_CONNECTOR_TYPE_CHADEMO = 4
    EV_CONNECTOR_TYPE_CCS_COMBO_1 = 5
    EV_CONNECTOR_TYPE_CCS_COMBO_2 = 6
    EV_CONNECTOR_TYPE_TESLA = 7
    EV_CONNECTOR_TYPE_UNSPECIFIED_GB_T = 8
    EV_CONNECTOR_TYPE_UNSPECIFIED_WALL_OUTLET = 9
    EV_CONNECTOR_TYPE_NACS = 10


class EVChargeOptions(proto.Message):
    r"""Information about the EV Charge Station hosted in Place. Terminology
    follows
    https://afdc.energy.gov/fuels/electricity_infrastructure.html One
    port could charge one car at a time. One port has one or more
    connectors. One station has one or more ports.

    Attributes:
        connector_count (int):
            Number of connectors at this station.
            However, because some ports can have multiple
            connectors but only be able to charge one car at
            a time (e.g.) the number of connectors may be
            greater than the total number of cars which can
            charge simultaneously.
        connector_aggregation (MutableSequence[google.maps.places_v1.types.EVChargeOptions.ConnectorAggregation]):
            A list of EV charging connector aggregations
            that contain connectors of the same type and
            same charge rate.
    """

    class ConnectorAggregation(proto.Message):
        r"""EV charging information grouped by [type, max_charge_rate_kw]. Shows
        EV charge aggregation of connectors that have the same type and max
        charge rate in kw.


        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            type_ (google.maps.places_v1.types.EVConnectorType):
                The connector type of this aggregation.
            max_charge_rate_kw (float):
                The static max charging rate in kw of each
                connector in the aggregation.
            count (int):
                Number of connectors in this aggregation.
            available_count (int):
                Number of connectors in this aggregation that
                are currently available.

                This field is a member of `oneof`_ ``_available_count``.
            out_of_service_count (int):
                Number of connectors in this aggregation that
                are currently out of service.

                This field is a member of `oneof`_ ``_out_of_service_count``.
            availability_last_update_time (google.protobuf.timestamp_pb2.Timestamp):
                The timestamp when the connector availability
                information in this aggregation was last
                updated.
        """

        type_: "EVConnectorType" = proto.Field(
            proto.ENUM,
            number=1,
            enum="EVConnectorType",
        )
        max_charge_rate_kw: float = proto.Field(
            proto.DOUBLE,
            number=2,
        )
        count: int = proto.Field(
            proto.INT32,
            number=3,
        )
        available_count: int = proto.Field(
            proto.INT32,
            number=4,
            optional=True,
        )
        out_of_service_count: int = proto.Field(
            proto.INT32,
            number=5,
            optional=True,
        )
        availability_last_update_time: timestamp_pb2.Timestamp = proto.Field(
            proto.MESSAGE,
            number=6,
            message=timestamp_pb2.Timestamp,
        )

    connector_count: int = proto.Field(
        proto.INT32,
        number=1,
    )
    connector_aggregation: MutableSequence[ConnectorAggregation] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message=ConnectorAggregation,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.type import localized_text_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.maps.places.v1",
    manifest={
        "AddressDescriptor",
    },
)


class AddressDescriptor(proto.Message):
    r"""A relational description of a location. Includes a ranked set
    of nearby landmarks and precise containing areas and their
    relationship to the target location.

    Attributes:
        landmarks (MutableSequence[google.maps.places_v1.types.AddressDescriptor.Landmark]):
            A ranked list of nearby landmarks. The most
            recognizable and nearby landmarks are ranked
            first.
        areas (MutableSequence[google.maps.places_v1.types.AddressDescriptor.Area]):
            A ranked list of containing or adjacent
            areas. The most recognizable and precise areas
            are ranked first.
    """

    class Landmark(proto.Message):
        r"""Basic landmark information and the landmark's relationship
        with the target location.

        Landmarks are prominent places that can be used to describe a
        location.


        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            name (str):
                The landmark's resource name.
            place_id (str):
                The landmark's place id.
            display_name (google.type.localized_text_pb2.LocalizedText):
                The landmark's display name.
            types (MutableSequence[str]):
                A set of type tags for this landmark. For a
                complete list of possible values, see
                https://developers.google.com/maps/documentation/places/web-service/place-types.
            spatial_relationship (google.maps.places_v1.types.AddressDescriptor.Landmark.SpatialRelationship):
                Defines the spatial relationship between the
                target location and the landmark.
            straight_line_distance_meters (float):
                The straight line distance, in meters, between the center
                point of the target and the center point of the landmark. In
                some situations, this value can be longer than
                ``travel_distance_meters``.
            travel_distance_meters (float):
                The travel distance, in meters, along the
                road network from the target to the landmark, if
                known. This value does not take into account the
                mode of transportation, such as walking,
                driving, or biking.

                This field is a member of `oneof`_ ``_travel_distance_meters``.
        """

        class SpatialRelationship(proto.Enum):
            r"""Defines the spatial relationship between the target location
            and the landmark.

            Values:
                NEAR (0):
                    This is the default relationship when nothing
                    more specific below applies.
                WITHIN (1):
                    The landmark has a spatial geometry and the
                    target is within its bounds.
                BESIDE (2):
                    The target is directly adjacent to the
                    landmark.
                ACROSS_THE_ROAD (3):
                    The target is directly opposite the landmark
                    on the other side of the road.
                DOWN_THE_ROAD (4):
                    On the same route as the landmark but not
                    besides or across.
                AROUND_THE_CORNER (5):
                    Not on the same route as the landmark but a
                    single turn away.
                BEHIND (6):
                    Close to the landmark's structure but further
                    away from its street entrances.
            """
            NEAR = 0
            WITHIN = 1
            BESIDE = 2
            ACROSS_THE_ROAD = 3
            DOWN_THE_ROAD = 4
            AROUND_THE_CORNER = 5
            BEHIND = 6

        name: str = proto.Field(
            proto.STRING,
            number=1,
        )
        place_id: str = proto.Field(
            proto.STRING,
            number=2,
        )
        display_name: localized_text_pb2.LocalizedText = proto.Field(
            proto.MESSAGE,
            number=3,
            message=localized_text_pb2.LocalizedText,
        )
        types: MutableSequence[str] = proto.RepeatedField(
            proto.STRING,
            number=4,
        )
        spatial_relationship: "AddressDescriptor.Landmark.SpatialRelationship" = (
            proto.Field(
                proto.ENUM,
                number=5,
                enum="AddressDescriptor.Landmark.SpatialRelationship",
            )
        )
        straight_line_distance_meters: float = proto.Field(
            proto.FLOAT,
            number=6,
        )
        travel_distance_meters: float = proto.Field(
            proto.FLOAT,
            number=7,
            optional=True,
        )

    class Area(proto.Message):
        r"""Area information and the area's relationship with the target
        location.
        Areas includes precise sublocality, neighborhoods, and large
        compounds that are useful for describing a location.

        Attributes:
            name (str):
                The area's resource name.
            place_id (str):
                The area's place id.
            display_name (google.type.localized_text_pb2.LocalizedText):
                The area's display name.
            containment (google.maps.places_v1.types.AddressDescriptor.Area.Containment):
                Defines the spatial relationship between the
                target location and the area.
        """

        class Containment(proto.Enum):
            r"""Defines the spatial relationship between the target location
            and the area.

            Values:
                CONTAINMENT_UNSPECIFIED (0):
                    The containment is unspecified.
                WITHIN (1):
                    The target location is within the area
                    region, close to the center.
                OUTSKIRTS (2):
                    The target location is within the area
                    region, close to the edge.
                NEAR (3):
                    The target location is outside the area
                    region, but close by.
            """
            CONTAINMENT_UNSPECIFIED = 0
            WITHIN = 1
            OUTSKIRTS = 2
            NEAR = 3

        name: str = proto.Field(
            proto.STRING,
            number=1,
        )
        place_id: str = proto.Field(
            proto.STRING,
            number=2,
        )
        display_name: localized_text_pb2.LocalizedText = proto.Field(
            proto.MESSAGE,
            number=3,
            message=localized_text_pb2.LocalizedText,
        )
        containment: "AddressDescriptor.Area.Containment" = proto.Field(
            proto.ENUM,
            number=4,
            enum="AddressDescriptor.Area.Containment",
        )

    landmarks: MutableSequence[Landmark] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=Landmark,
    )
    areas: MutableSequence[Area] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message=Area,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.maps.places.v1",
    manifest={
        "Polyline",
    },
)


class Polyline(proto.Message):
    r"""A route polyline. Only supports an `encoded
    polyline <https://developers.google.com/maps/documentation/utilities/polylinealgorithm>`__,
    which can be passed as a string and includes compression with
    minimal lossiness. This is the Routes API default output.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        encoded_polyline (str):
            An `encoded
            polyline <https://developers.google.com/maps/documentation/utilities/polylinealgorithm>`__,
            as returned by the `Routes API by
            default <https://developers.google.com/maps/documentation/routes/reference/rest/v2/TopLevel/computeRoutes#polylineencoding>`__.
            See the
            `encoder <https://developers.google.com/maps/documentation/utilities/polylineutility>`__
            and
            `decoder <https://developers.google.com/maps/documentation/routes/polylinedecoder>`__
            tools.

            This field is a member of `oneof`_ ``polyline_type``.
    """

    encoded_polyline: str = proto.Field(
        proto.STRING,
        number=1,
        oneof="polyline_type",
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.maps.places_v1.types import attribution

__protobuf__ = proto.module(
    package="google.maps.places.v1",
    manifest={
        "Photo",
    },
)


class Photo(proto.Message):
    r"""Information about a photo of a place.

    Attributes:
        name (str):
            Identifier. A reference representing this place photo which
            may be used to look up this place photo again (also called
            the API "resource" name:
            ``places/{place_id}/photos/{photo}``).
        width_px (int):
            The maximum available width, in pixels.
        height_px (int):
            The maximum available height, in pixels.
        author_attributions (MutableSequence[google.maps.places_v1.types.AuthorAttribution]):
            This photo's authors.
        flag_content_uri (str):
            A link where users can flag a problem with
            the photo.
        google_maps_uri (str):
            A link to show the photo on Google Maps.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    width_px: int = proto.Field(
        proto.INT32,
        number=2,
    )
    height_px: int = proto.Field(
        proto.INT32,
        number=3,
    )
    author_attributions: MutableSequence[
        attribution.AuthorAttribution
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=4,
        message=attribution.AuthorAttribution,
    )
    flag_content_uri: str = proto.Field(
        proto.STRING,
        number=5,
    )
    google_maps_uri: str = proto.Field(
        proto.STRING,
        number=6,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.geo.type.types import viewport
from google.type import latlng_pb2  # type: ignore
import proto  # type: ignore

from google.maps.places_v1.types import contextual_content, ev_charging, geometry
from google.maps.places_v1.types import routing_preference as gmp_routing_preference
from google.maps.places_v1.types import place as gmp_place
from google.maps.places_v1.types import polyline as gmp_polyline
from google.maps.places_v1.types import route_modifiers as gmp_route_modifiers
from google.maps.places_v1.types import routing_summary
from google.maps.places_v1.types import travel_mode as gmp_travel_mode

__protobuf__ = proto.module(
    package="google.maps.places.v1",
    manifest={
        "RoutingParameters",
        "SearchNearbyRequest",
        "SearchNearbyResponse",
        "SearchTextRequest",
        "SearchTextResponse",
        "GetPhotoMediaRequest",
        "PhotoMedia",
        "GetPlaceRequest",
        "AutocompletePlacesRequest",
        "AutocompletePlacesResponse",
    },
)


class RoutingParameters(proto.Message):
    r"""Parameters to configure the routing calculations to the
    places in the response, both along a route (where result ranking
    will be influenced) and for calculating travel times on results.

    Attributes:
        origin (google.type.latlng_pb2.LatLng):
            Optional. An explicit routing origin that
            overrides the origin defined in the polyline. By
            default, the polyline origin is used.
        travel_mode (google.maps.places_v1.types.TravelMode):
            Optional. The travel mode.
        route_modifiers (google.maps.places_v1.types.RouteModifiers):
            Optional. The route modifiers.
        routing_preference (google.maps.places_v1.types.RoutingPreference):
            Optional. Specifies how to compute the routing summaries.
            The server attempts to use the selected routing preference
            to compute the route. The traffic aware routing preference
            is only available for the ``DRIVE`` or ``TWO_WHEELER``
            ``travelMode``.
    """

    origin: latlng_pb2.LatLng = proto.Field(
        proto.MESSAGE,
        number=1,
        message=latlng_pb2.LatLng,
    )
    travel_mode: gmp_travel_mode.TravelMode = proto.Field(
        proto.ENUM,
        number=2,
        enum=gmp_travel_mode.TravelMode,
    )
    route_modifiers: gmp_route_modifiers.RouteModifiers = proto.Field(
        proto.MESSAGE,
        number=3,
        message=gmp_route_modifiers.RouteModifiers,
    )
    routing_preference: gmp_routing_preference.RoutingPreference = proto.Field(
        proto.ENUM,
        number=4,
        enum=gmp_routing_preference.RoutingPreference,
    )


class SearchNearbyRequest(proto.Message):
    r"""Request proto for Search Nearby.

    Attributes:
        language_code (str):
            Place details will be displayed with the
            preferred language if available. If the language
            code is unspecified or unrecognized, place
            details of any language may be returned, with a
            preference for English if such details exist.

            Current list of supported languages:

            https://developers.google.com/maps/faq#languagesupport.
        region_code (str):
            The Unicode country/region code (CLDR) of the location where
            the request is coming from. This parameter is used to
            display the place details, like region-specific place name,
            if available. The parameter can affect results based on
            applicable law.

            For more information, see
            https://www.unicode.org/cldr/charts/latest/supplemental/territory_language_information.html.

            Note that 3-digit region codes are not currently supported.
        included_types (MutableSequence[str]):
            Included Place type (eg, "restaurant" or "gas_station") from
            https://developers.google.com/maps/documentation/places/web-service/place-types.

            Up to 50 types from `Table
            A <https://developers.google.com/maps/documentation/places/web-service/place-types#table-a>`__
            may be specified.

            If there are any conflicting types, i.e. a type appears in
            both included_types and excluded_types, an INVALID_ARGUMENT
            error is returned.

            If a Place type is specified with multiple type
            restrictions, only places that satisfy all of the
            restrictions are returned. For example, if we have
            {included_types = ["restaurant"], excluded_primary_types =
            ["restaurant"]}, the returned places provide "restaurant"
            related services but do not operate primarily as
            "restaurants".
        excluded_types (MutableSequence[str]):
            Excluded Place type (eg, "restaurant" or "gas_station") from
            https://developers.google.com/maps/documentation/places/web-service/place-types.

            Up to 50 types from `Table
            A <https://developers.google.com/maps/documentation/places/web-service/place-types#table-a>`__
            may be specified.

            If the client provides both included_types (e.g. restaurant)
            and excluded_types (e.g. cafe), then the response should
            include places that are restaurant but not cafe. The
            response includes places that match at least one of the
            included_types and none of the excluded_types.

            If there are any conflicting types, i.e. a type appears in
            both included_types and excluded_types, an INVALID_ARGUMENT
            error is returned.

            If a Place type is specified with multiple type
            restrictions, only places that satisfy all of the
            restrictions are returned. For example, if we have
            {included_types = ["restaurant"], excluded_primary_types =
            ["restaurant"]}, the returned places provide "restaurant"
            related services but do not operate primarily as
            "restaurants".
        included_primary_types (MutableSequence[str]):
            Included primary Place type (e.g. "restaurant" or
            "gas_station") from
            https://developers.google.com/maps/documentation/places/web-service/place-types.
            A place can only have a single primary type from the
            supported types table associated with it.

            Up to 50 types from `Table
            A <https://developers.google.com/maps/documentation/places/web-service/place-types#table-a>`__
            may be specified.

            If there are any conflicting primary types, i.e. a type
            appears in both included_primary_types and
            excluded_primary_types, an INVALID_ARGUMENT error is
            returned.

            If a Place type is specified with multiple type
            restrictions, only places that satisfy all of the
            restrictions are returned. For example, if we have
            {included_types = ["restaurant"], excluded_primary_types =
            ["restaurant"]}, the returned places provide "restaurant"
            related services but do not operate primarily as
            "restaurants".
        excluded_primary_types (MutableSequence[str]):
            Excluded primary Place type (e.g. "restaurant" or
            "gas_station") from
            https://developers.google.com/maps/documentation/places/web-service/place-types.

            Up to 50 types from `Table
            A <https://developers.google.com/maps/documentation/places/web-service/place-types#table-a>`__
            may be specified.

            If there are any conflicting primary types, i.e. a type
            appears in both included_primary_types and
            excluded_primary_types, an INVALID_ARGUMENT error is
            returned.

            If a Place type is specified with multiple type
            restrictions, only places that satisfy all of the
            restrictions are returned. For example, if we have
            {included_types = ["restaurant"], excluded_primary_types =
            ["restaurant"]}, the returned places provide "restaurant"
            related services but do not operate primarily as
            "restaurants".
        max_result_count (int):
            Maximum number of results to return. It must be between 1
            and 20 (default), inclusively. If the number is unset, it
            falls back to the upper limit. If the number is set to
            negative or exceeds the upper limit, an INVALID_ARGUMENT
            error is returned.
        location_restriction (google.maps.places_v1.types.SearchNearbyRequest.LocationRestriction):
            Required. The region to search.
        rank_preference (google.maps.places_v1.types.SearchNearbyRequest.RankPreference):
            How results will be ranked in the response.
        routing_parameters (google.maps.places_v1.types.RoutingParameters):
            Optional. Parameters that affect the routing
            to the search results.
    """

    class RankPreference(proto.Enum):
        r"""How results will be ranked in the response.

        Values:
            RANK_PREFERENCE_UNSPECIFIED (0):
                RankPreference value not set. Will use rank
                by POPULARITY by default.
            DISTANCE (1):
                Ranks results by distance.
            POPULARITY (2):
                Ranks results by popularity.
        """
        RANK_PREFERENCE_UNSPECIFIED = 0
        DISTANCE = 1
        POPULARITY = 2

    class LocationRestriction(proto.Message):
        r"""The region to search.

        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            circle (google.maps.places_v1.types.Circle):
                A circle defined by center point and radius.

                This field is a member of `oneof`_ ``type``.
        """

        circle: geometry.Circle = proto.Field(
            proto.MESSAGE,
            number=2,
            oneof="type",
            message=geometry.Circle,
        )

    language_code: str = proto.Field(
        proto.STRING,
        number=1,
    )
    region_code: str = proto.Field(
        proto.STRING,
        number=2,
    )
    included_types: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )
    excluded_types: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=4,
    )
    included_primary_types: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=5,
    )
    excluded_primary_types: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=6,
    )
    max_result_count: int = proto.Field(
        proto.INT32,
        number=7,
    )
    location_restriction: LocationRestriction = proto.Field(
        proto.MESSAGE,
        number=8,
        message=LocationRestriction,
    )
    rank_preference: RankPreference = proto.Field(
        proto.ENUM,
        number=9,
        enum=RankPreference,
    )
    routing_parameters: "RoutingParameters" = proto.Field(
        proto.MESSAGE,
        number=10,
        message="RoutingParameters",
    )


class SearchNearbyResponse(proto.Message):
    r"""Response proto for Search Nearby.

    Attributes:
        places (MutableSequence[google.maps.places_v1.types.Place]):
            A list of places that meets user's
            requirements like places types, number of places
            and specific location restriction.
        routing_summaries (MutableSequence[google.maps.places_v1.types.RoutingSummary]):
            A list of routing summaries where each entry associates to
            the corresponding place in the same index in the ``places``
            field. If the routing summary is not available for one of
            the places, it will contain an empty entry. This list should
            have as many entries as the list of places if requested.
    """

    places: MutableSequence[gmp_place.Place] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=gmp_place.Place,
    )
    routing_summaries: MutableSequence[
        routing_summary.RoutingSummary
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message=routing_summary.RoutingSummary,
    )


class SearchTextRequest(proto.Message):
    r"""Request proto for SearchText.

    Attributes:
        text_query (str):
            Required. The text query for textual search.
        language_code (str):
            Place details will be displayed with the
            preferred language if available. If the language
            code is unspecified or unrecognized, place
            details of any language may be returned, with a
            preference for English if such details exist.

            Current list of supported languages:

            https://developers.google.com/maps/faq#languagesupport.
        region_code (str):
            The Unicode country/region code (CLDR) of the location where
            the request is coming from. This parameter is used to
            display the place details, like region-specific place name,
            if available. The parameter can affect results based on
            applicable law.

            For more information, see
            https://www.unicode.org/cldr/charts/latest/supplemental/territory_language_information.html.

            Note that 3-digit region codes are not currently supported.
        rank_preference (google.maps.places_v1.types.SearchTextRequest.RankPreference):
            How results will be ranked in the response.
        included_type (str):
            The requested place type. Full list of types
            supported:
            https://developers.google.com/maps/documentation/places/web-service/place-types.
            Only support one included type.
        open_now (bool):
            Used to restrict the search to places that
            are currently open.  The default is false.
        min_rating (float):
            Filter out results whose average user rating is strictly
            less than this limit. A valid value must be a float between
            0 and 5 (inclusively) at a 0.5 cadence i.e. [0, 0.5, 1.0,
            ... , 5.0] inclusively. The input rating will round up to
            the nearest 0.5(ceiling). For instance, a rating of 0.6 will
            eliminate all results with a less than 1.0 rating.
        max_result_count (int):
            Maximum number of results to return. It must be between 1
            and 20, inclusively. The default is 20. If the number is
            unset, it falls back to the upper limit. If the number is
            set to negative or exceeds the upper limit, an
            INVALID_ARGUMENT error is returned.
        price_levels (MutableSequence[google.maps.places_v1.types.PriceLevel]):
            Used to restrict the search to places that
            are marked as certain price levels. Users can
            choose any combinations of price levels. Default
            to select all price levels.
        strict_type_filtering (bool):
            Used to set strict type filtering for included_type. If set
            to true, only results of the same type will be returned.
            Default to false.
        location_bias (google.maps.places_v1.types.SearchTextRequest.LocationBias):
            The region to search. This location serves as a bias which
            means results around given location might be returned.
            Cannot be set along with location_restriction.
        location_restriction (google.maps.places_v1.types.SearchTextRequest.LocationRestriction):
            The region to search. This location serves as a restriction
            which means results outside given location will not be
            returned. Cannot be set along with location_bias.
        ev_options (google.maps.places_v1.types.SearchTextRequest.EVOptions):
            Optional. Set the searchable EV options of a
            place search request.
        routing_parameters (google.maps.places_v1.types.RoutingParameters):
            Optional. Additional parameters for routing
            to results.
        search_along_route_parameters (google.maps.places_v1.types.SearchTextRequest.SearchAlongRouteParameters):
            Optional. Additional parameters proto for
            searching along a route.
        include_pure_service_area_businesses (bool):
            Optional. Include pure service area businesses if the field
            is set to true. Pure service area business is a business
            that visits or delivers to customers directly but does not
            serve customers at their business address. For example,
            businesses like cleaning services or plumbers. Those
            businesses do not have a physical address or location on
            Google Maps. Places will not return fields including
            ``location``, ``plus_code``, and other location related
            fields for these businesses.
    """

    class RankPreference(proto.Enum):
        r"""How results will be ranked in the response.

        Values:
            RANK_PREFERENCE_UNSPECIFIED (0):
                For a categorical query such as "Restaurants
                in New York City", RELEVANCE is the default. For
                non-categorical queries such as "Mountain View,
                CA" we recommend that you leave rankPreference
                unset.
            DISTANCE (1):
                Ranks results by distance.
            RELEVANCE (2):
                Ranks results by relevance. Sort order
                determined by normal ranking stack.
        """
        RANK_PREFERENCE_UNSPECIFIED = 0
        DISTANCE = 1
        RELEVANCE = 2

    class LocationBias(proto.Message):
        r"""The region to search. This location serves as a bias which
        means results around given location might be returned.

        This message has `oneof`_ fields (mutually exclusive fields).
        For each oneof, at most one member field can be set at the same time.
        Setting any member of the oneof automatically clears all other
        members.

        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            rectangle (google.geo.type.types.Viewport):
                A rectangle box defined by northeast and southwest corner.
                ``rectangle.high()`` must be the northeast point of the
                rectangle viewport. ``rectangle.low()`` must be the
                southwest point of the rectangle viewport.
                ``rectangle.low().latitude()`` cannot be greater than
                ``rectangle.high().latitude()``. This will result in an
                empty latitude range. A rectangle viewport cannot be wider
                than 180 degrees.

                This field is a member of `oneof`_ ``type``.
            circle (google.maps.places_v1.types.Circle):
                A circle defined by center point and radius.

                This field is a member of `oneof`_ ``type``.
        """

        rectangle: viewport.Viewport = proto.Field(
            proto.MESSAGE,
            number=1,
            oneof="type",
            message=viewport.Viewport,
        )
        circle: geometry.Circle = proto.Field(
            proto.MESSAGE,
            number=2,
            oneof="type",
            message=geometry.Circle,
        )

    class LocationRestriction(proto.Message):
        r"""The region to search. This location serves as a restriction
        which means results outside given location will not be returned.


        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            rectangle (google.geo.type.types.Viewport):
                A rectangle box defined by northeast and southwest corner.
                ``rectangle.high()`` must be the northeast point of the
                rectangle viewport. ``rectangle.low()`` must be the
                southwest point of the rectangle viewport.
                ``rectangle.low().latitude()`` cannot be greater than
                ``rectangle.high().latitude()``. This will result in an
                empty latitude range. A rectangle viewport cannot be wider
                than 180 degrees.

                This field is a member of `oneof`_ ``type``.
        """

        rectangle: viewport.Viewport = proto.Field(
            proto.MESSAGE,
            number=1,
            oneof="type",
            message=viewport.Viewport,
        )

    class EVOptions(proto.Message):
        r"""Searchable EV options of a place search request.

        Attributes:
            minimum_charging_rate_kw (float):
                Optional. Minimum required charging rate in
                kilowatts. A place with a charging rate less
                than the specified rate is filtered out.
            connector_types (MutableSequence[google.maps.places_v1.types.EVConnectorType]):
                Optional. The list of preferred EV connector
                types. A place that does not support any of the
                listed connector types is filtered out.
        """

        minimum_charging_rate_kw: float = proto.Field(
            proto.DOUBLE,
            number=1,
        )
        connector_types: MutableSequence[
            ev_charging.EVConnectorType
        ] = proto.RepeatedField(
            proto.ENUM,
            number=2,
            enum=ev_charging.EVConnectorType,
        )

    class SearchAlongRouteParameters(proto.Message):
        r"""Specifies a precalculated polyline from the `Routes
        API <https://developers.google.com/maps/documentation/routes>`__
        defining the route to search. Searching along a route is similar to
        using the ``locationBias`` or ``locationRestriction`` request option
        to bias the search results. However, while the ``locationBias`` and
        ``locationRestriction`` options let you specify a region to bias the
        search results, this option lets you bias the results along a trip
        route.

        Results are not guaranteed to be along the route provided, but
        rather are ranked within the search area defined by the polyline
        and, optionally, by the ``locationBias`` or ``locationRestriction``
        based on minimal detour times from origin to destination. The
        results might be along an alternate route, especially if the
        provided polyline does not define an optimal route from origin to
        destination.

        Attributes:
            polyline (google.maps.places_v1.types.Polyline):
                Required. The route polyline.
        """

        polyline: gmp_polyline.Polyline = proto.Field(
            proto.MESSAGE,
            number=1,
            message=gmp_polyline.Polyline,
        )

    text_query: str = proto.Field(
        proto.STRING,
        number=1,
    )
    language_code: str = proto.Field(
        proto.STRING,
        number=2,
    )
    region_code: str = proto.Field(
        proto.STRING,
        number=3,
    )
    rank_preference: RankPreference = proto.Field(
        proto.ENUM,
        number=4,
        enum=RankPreference,
    )
    included_type: str = proto.Field(
        proto.STRING,
        number=6,
    )
    open_now: bool = proto.Field(
        proto.BOOL,
        number=7,
    )
    min_rating: float = proto.Field(
        proto.DOUBLE,
        number=9,
    )
    max_result_count: int = proto.Field(
        proto.INT32,
        number=10,
    )
    price_levels: MutableSequence[gmp_place.PriceLevel] = proto.RepeatedField(
        proto.ENUM,
        number=11,
        enum=gmp_place.PriceLevel,
    )
    strict_type_filtering: bool = proto.Field(
        proto.BOOL,
        number=12,
    )
    location_bias: LocationBias = proto.Field(
        proto.MESSAGE,
        number=13,
        message=LocationBias,
    )
    location_restriction: LocationRestriction = proto.Field(
        proto.MESSAGE,
        number=14,
        message=LocationRestriction,
    )
    ev_options: EVOptions = proto.Field(
        proto.MESSAGE,
        number=15,
        message=EVOptions,
    )
    routing_parameters: "RoutingParameters" = proto.Field(
        proto.MESSAGE,
        number=16,
        message="RoutingParameters",
    )
    search_along_route_parameters: SearchAlongRouteParameters = proto.Field(
        proto.MESSAGE,
        number=17,
        message=SearchAlongRouteParameters,
    )
    include_pure_service_area_businesses: bool = proto.Field(
        proto.BOOL,
        number=20,
    )


class SearchTextResponse(proto.Message):
    r"""Response proto for SearchText.

    Attributes:
        places (MutableSequence[google.maps.places_v1.types.Place]):
            A list of places that meet the user's text
            search criteria.
        routing_summaries (MutableSequence[google.maps.places_v1.types.RoutingSummary]):
            A list of routing summaries where each entry associates to
            the corresponding place in the same index in the ``places``
            field. If the routing summary is not available for one of
            the places, it will contain an empty entry. This list will
            have as many entries as the list of places if requested.
        contextual_contents (MutableSequence[google.maps.places_v1.types.ContextualContent]):
            Experimental: See
            https://developers.google.com/maps/documentation/places/web-service/experimental/places-generative
            for more details.

            A list of contextual contents where each entry associates to
            the corresponding place in the same index in the places
            field. The contents that are relevant to the ``text_query``
            in the request are preferred. If the contextual content is
            not available for one of the places, it will return
            non-contextual content. It will be empty only when the
            content is unavailable for this place. This list will have
            as many entries as the list of places if requested.
    """

    places: MutableSequence[gmp_place.Place] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=gmp_place.Place,
    )
    routing_summaries: MutableSequence[
        routing_summary.RoutingSummary
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message=routing_summary.RoutingSummary,
    )
    contextual_contents: MutableSequence[
        contextual_content.ContextualContent
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message=contextual_content.ContextualContent,
    )


class GetPhotoMediaRequest(proto.Message):
    r"""Request for fetching a photo of a place using a photo
    resource name.

    Attributes:
        name (str):
            Required. The resource name of a photo media in the format:
            ``places/{place_id}/photos/{photo_reference}/media``.

            The resource name of a photo as returned in a Place object's
            ``photos.name`` field comes with the format
            ``places/{place_id}/photos/{photo_reference}``. You need to
            append ``/media`` at the end of the photo resource to get
            the photo media resource name.
        max_width_px (int):
            Optional. Specifies the maximum desired width, in pixels, of
            the image. If the image is smaller than the values
            specified, the original image will be returned. If the image
            is larger in either dimension, it will be scaled to match
            the smaller of the two dimensions, restricted to its
            original aspect ratio. Both the max_height_px and
            max_width_px properties accept an integer between 1 and
            4800, inclusively. If the value is not within the allowed
            range, an INVALID_ARGUMENT error will be returned.

            At least one of max_height_px or max_width_px needs to be
            specified. If neither max_height_px nor max_width_px is
            specified, an INVALID_ARGUMENT error will be returned.
        max_height_px (int):
            Optional. Specifies the maximum desired height, in pixels,
            of the image. If the image is smaller than the values
            specified, the original image will be returned. If the image
            is larger in either dimension, it will be scaled to match
            the smaller of the two dimensions, restricted to its
            original aspect ratio. Both the max_height_px and
            max_width_px properties accept an integer between 1 and
            4800, inclusively. If the value is not within the allowed
            range, an INVALID_ARGUMENT error will be returned.

            At least one of max_height_px or max_width_px needs to be
            specified. If neither max_height_px nor max_width_px is
            specified, an INVALID_ARGUMENT error will be returned.
        skip_http_redirect (bool):
            Optional. If set, skip the default HTTP
            redirect behavior and render a text format (for
            example, in JSON format for HTTP use case)
            response. If not set, an HTTP redirect will be
            issued to redirect the call to the image media.
            This option is ignored for non-HTTP requests.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    max_width_px: int = proto.Field(
        proto.INT32,
        number=2,
    )
    max_height_px: int = proto.Field(
        proto.INT32,
        number=3,
    )
    skip_http_redirect: bool = proto.Field(
        proto.BOOL,
        number=4,
    )


class PhotoMedia(proto.Message):
    r"""A photo media from Places API.

    Attributes:
        name (str):
            The resource name of a photo media in the format:
            ``places/{place_id}/photos/{photo_reference}/media``.
        photo_uri (str):
            A short-lived uri that can be used to render
            the photo.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    photo_uri: str = proto.Field(
        proto.STRING,
        number=2,
    )


class GetPlaceRequest(proto.Message):
    r"""Request for fetching a Place based on its resource name, which is a
    string in the ``places/{place_id}`` format.

    Attributes:
        name (str):
            Required. The resource name of a place, in the
            ``places/{place_id}`` format.
        language_code (str):
            Optional. Place details will be displayed
            with the preferred language if available.

            Current list of supported languages:

            https://developers.google.com/maps/faq#languagesupport.
        region_code (str):
            Optional. The Unicode country/region code (CLDR) of the
            location where the request is coming from. This parameter is
            used to display the place details, like region-specific
            place name, if available. The parameter can affect results
            based on applicable law. For more information, see
            https://www.unicode.org/cldr/charts/latest/supplemental/territory_language_information.html.

            Note that 3-digit region codes are not currently supported.
        session_token (str):
            Optional. A string which identifies an Autocomplete session
            for billing purposes. Must be a URL and filename safe base64
            string with at most 36 ASCII characters in length. Otherwise
            an INVALID_ARGUMENT error is returned.

            The session begins when the user starts typing a query, and
            concludes when they select a place and a call to Place
            Details or Address Validation is made. Each session can have
            multiple queries, followed by one Place Details or Address
            Validation request. The credentials used for each request
            within a session must belong to the same Google Cloud
            Console project. Once a session has concluded, the token is
            no longer valid; your app must generate a fresh token for
            each session. If the ``session_token`` parameter is omitted,
            or if you reuse a session token, the session is charged as
            if no session token was provided (each request is billed
            separately).

            We recommend the following guidelines:

            -  Use session tokens for all Place Autocomplete calls.
            -  Generate a fresh token for each session. Using a version
               4 UUID is recommended.
            -  Ensure that the credentials used for all Place
               Autocomplete, Place Details, and Address Validation
               requests within a session belong to the same Cloud
               Console project.
            -  Be sure to pass a unique session token for each new
               session. Using the same token for more than one session
               will result in each request being billed individually.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    language_code: str = proto.Field(
        proto.STRING,
        number=2,
    )
    region_code: str = proto.Field(
        proto.STRING,
        number=3,
    )
    session_token: str = proto.Field(
        proto.STRING,
        number=4,
    )


class AutocompletePlacesRequest(proto.Message):
    r"""Request proto for AutocompletePlaces.

    Attributes:
        input (str):
            Required. The text string on which to search.
        location_bias (google.maps.places_v1.types.AutocompletePlacesRequest.LocationBias):
            Optional. Bias results to a specified location.

            At most one of ``location_bias`` or ``location_restriction``
            should be set. If neither are set, the results will be
            biased by IP address, meaning the IP address will be mapped
            to an imprecise location and used as a biasing signal.
        location_restriction (google.maps.places_v1.types.AutocompletePlacesRequest.LocationRestriction):
            Optional. Restrict results to a specified location.

            At most one of ``location_bias`` or ``location_restriction``
            should be set. If neither are set, the results will be
            biased by IP address, meaning the IP address will be mapped
            to an imprecise location and used as a biasing signal.
        included_primary_types (MutableSequence[str]):
            Optional. Included primary Place type (for example,
            "restaurant" or "gas_station") in Place Types
            (https://developers.google.com/maps/documentation/places/web-service/place-types),
            or only ``(regions)``, or only ``(cities)``. A Place is only
            returned if its primary type is included in this list. Up to
            5 values can be specified. If no types are specified, all
            Place types are returned.
        included_region_codes (MutableSequence[str]):
            Optional. Only include results in the specified regions,
            specified as up to 15 CLDR two-character region codes. An
            empty set will not restrict the results. If both
            ``location_restriction`` and ``included_region_codes`` are
            set, the results will be located in the area of
            intersection.
        language_code (str):
            Optional. The language in which to return results. Defaults
            to en-US. The results may be in mixed languages if the
            language used in ``input`` is different from
            ``language_code`` or if the returned Place does not have a
            translation from the local language to ``language_code``.
        region_code (str):
            Optional. The region code, specified as a CLDR two-character
            region code. This affects address formatting, result
            ranking, and may influence what results are returned. This
            does not restrict results to the specified region. To
            restrict results to a region, use
            ``region_code_restriction``.
        origin (google.type.latlng_pb2.LatLng):
            Optional. The origin point from which to calculate geodesic
            distance to the destination (returned as
            ``distance_meters``). If this value is omitted, geodesic
            distance will not be returned.
        input_offset (int):
            Optional. A zero-based Unicode character offset of ``input``
            indicating the cursor position in ``input``. The cursor
            position may influence what predictions are returned.

            If empty, defaults to the length of ``input``.
        include_query_predictions (bool):
            Optional. If true, the response will include
            both Place and query predictions. Otherwise the
            response will only return Place predictions.
        session_token (str):
            Optional. A string which identifies an Autocomplete session
            for billing purposes. Must be a URL and filename safe base64
            string with at most 36 ASCII characters in length. Otherwise
            an INVALID_ARGUMENT error is returned.

            The session begins when the user starts typing a query, and
            concludes when they select a place and a call to Place
            Details or Address Validation is made. Each session can have
            multiple queries, followed by one Place Details or Address
            Validation request. The credentials used for each request
            within a session must belong to the same Google Cloud
            Console project. Once a session has concluded, the token is
            no longer valid; your app must generate a fresh token for
            each session. If the ``session_token`` parameter is omitted,
            or if you reuse a session token, the session is charged as
            if no session token was provided (each request is billed
            separately).

            We recommend the following guidelines:

            -  Use session tokens for all Place Autocomplete calls.
            -  Generate a fresh token for each session. Using a version
               4 UUID is recommended.
            -  Ensure that the credentials used for all Place
               Autocomplete, Place Details, and Address Validation
               requests within a session belong to the same Cloud
               Console project.
            -  Be sure to pass a unique session token for each new
               session. Using the same token for more than one session
               will result in each request being billed individually.
        include_pure_service_area_businesses (bool):
            Optional. Include pure service area businesses if the field
            is set to true. Pure service area business is a business
            that visits or delivers to customers directly but does not
            serve customers at their business address. For example,
            businesses like cleaning services or plumbers. Those
            businesses do not have a physical address or location on
            Google Maps. Places will not return fields including
            ``location``, ``plus_code``, and other location related
            fields for these businesses.
    """

    class LocationBias(proto.Message):
        r"""The region to search. The results may be biased around the
        specified region.

        This message has `oneof`_ fields (mutually exclusive fields).
        For each oneof, at most one member field can be set at the same time.
        Setting any member of the oneof automatically clears all other
        members.

        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            rectangle (google.geo.type.types.Viewport):
                A viewport defined by a northeast and a
                southwest corner.

                This field is a member of `oneof`_ ``type``.
            circle (google.maps.places_v1.types.Circle):
                A circle defined by a center point and
                radius.

                This field is a member of `oneof`_ ``type``.
        """

        rectangle: viewport.Viewport = proto.Field(
            proto.MESSAGE,
            number=1,
            oneof="type",
            message=viewport.Viewport,
        )
        circle: geometry.Circle = proto.Field(
            proto.MESSAGE,
            number=2,
            oneof="type",
            message=geometry.Circle,
        )

    class LocationRestriction(proto.Message):
        r"""The region to search. The results will be restricted to the
        specified region.

        This message has `oneof`_ fields (mutually exclusive fields).
        For each oneof, at most one member field can be set at the same time.
        Setting any member of the oneof automatically clears all other
        members.

        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            rectangle (google.geo.type.types.Viewport):
                A viewport defined by a northeast and a
                southwest corner.

                This field is a member of `oneof`_ ``type``.
            circle (google.maps.places_v1.types.Circle):
                A circle defined by a center point and
                radius.

                This field is a member of `oneof`_ ``type``.
        """

        rectangle: viewport.Viewport = proto.Field(
            proto.MESSAGE,
            number=1,
            oneof="type",
            message=viewport.Viewport,
        )
        circle: geometry.Circle = proto.Field(
            proto.MESSAGE,
            number=2,
            oneof="type",
            message=geometry.Circle,
        )

    input: str = proto.Field(
        proto.STRING,
        number=1,
    )
    location_bias: LocationBias = proto.Field(
        proto.MESSAGE,
        number=2,
        message=LocationBias,
    )
    location_restriction: LocationRestriction = proto.Field(
        proto.MESSAGE,
        number=3,
        message=LocationRestriction,
    )
    included_primary_types: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=4,
    )
    included_region_codes: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=5,
    )
    language_code: str = proto.Field(
        proto.STRING,
        number=6,
    )
    region_code: str = proto.Field(
        proto.STRING,
        number=7,
    )
    origin: latlng_pb2.LatLng = proto.Field(
        proto.MESSAGE,
        number=8,
        message=latlng_pb2.LatLng,
    )
    input_offset: int = proto.Field(
        proto.INT32,
        number=9,
    )
    include_query_predictions: bool = proto.Field(
        proto.BOOL,
        number=10,
    )
    session_token: str = proto.Field(
        proto.STRING,
        number=11,
    )
    include_pure_service_area_businesses: bool = proto.Field(
        proto.BOOL,
        number=12,
    )


class AutocompletePlacesResponse(proto.Message):
    r"""Response proto for AutocompletePlaces.

    Attributes:
        suggestions (MutableSequence[google.maps.places_v1.types.AutocompletePlacesResponse.Suggestion]):
            Contains a list of suggestions, ordered in
            descending order of relevance.
    """

    class Suggestion(proto.Message):
        r"""An Autocomplete suggestion result.

        This message has `oneof`_ fields (mutually exclusive fields).
        For each oneof, at most one member field can be set at the same time.
        Setting any member of the oneof automatically clears all other
        members.

        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            place_prediction (google.maps.places_v1.types.AutocompletePlacesResponse.Suggestion.PlacePrediction):
                A prediction for a Place.

                This field is a member of `oneof`_ ``kind``.
            query_prediction (google.maps.places_v1.types.AutocompletePlacesResponse.Suggestion.QueryPrediction):
                A prediction for a query.

                This field is a member of `oneof`_ ``kind``.
        """

        class StringRange(proto.Message):
            r"""Identifies a substring within a given text.

            Attributes:
                start_offset (int):
                    Zero-based offset of the first Unicode
                    character of the string (inclusive).
                end_offset (int):
                    Zero-based offset of the last Unicode
                    character (exclusive).
            """

            start_offset: int = proto.Field(
                proto.INT32,
                number=1,
            )
            end_offset: int = proto.Field(
                proto.INT32,
                number=2,
            )

        class FormattableText(proto.Message):
            r"""Text representing a Place or query prediction. The text may
            be used as is or formatted.

            Attributes:
                text (str):
                    Text that may be used as is or formatted with ``matches``.
                matches (MutableSequence[google.maps.places_v1.types.AutocompletePlacesResponse.Suggestion.StringRange]):
                    A list of string ranges identifying where the input request
                    matched in ``text``. The ranges can be used to format
                    specific parts of ``text``. The substrings may not be exact
                    matches of ``input`` if the matching was determined by
                    criteria other than string matching (for example, spell
                    corrections or transliterations).

                    These values are Unicode character offsets of ``text``. The
                    ranges are guaranteed to be ordered in increasing offset
                    values.
            """

            text: str = proto.Field(
                proto.STRING,
                number=1,
            )
            matches: MutableSequence[
                "AutocompletePlacesResponse.Suggestion.StringRange"
            ] = proto.RepeatedField(
                proto.MESSAGE,
                number=2,
                message="AutocompletePlacesResponse.Suggestion.StringRange",
            )

        class StructuredFormat(proto.Message):
            r"""Contains a breakdown of a Place or query prediction into main
            text and secondary text.

            For Place predictions, the main text contains the specific name
            of the Place. For query predictions, the main text contains the
            query.

            The secondary text contains additional disambiguating features
            (such as a city or region) to further identify the Place or
            refine the query.

            Attributes:
                main_text (google.maps.places_v1.types.AutocompletePlacesResponse.Suggestion.FormattableText):
                    Represents the name of the Place or query.
                secondary_text (google.maps.places_v1.types.AutocompletePlacesResponse.Suggestion.FormattableText):
                    Represents additional disambiguating features
                    (such as a city or region) to further identify
                    the Place or refine the query.
            """

            main_text: "AutocompletePlacesResponse.Suggestion.FormattableText" = (
                proto.Field(
                    proto.MESSAGE,
                    number=1,
                    message="AutocompletePlacesResponse.Suggestion.FormattableText",
                )
            )
            secondary_text: "AutocompletePlacesResponse.Suggestion.FormattableText" = (
                proto.Field(
                    proto.MESSAGE,
                    number=2,
                    message="AutocompletePlacesResponse.Suggestion.FormattableText",
                )
            )

        class PlacePrediction(proto.Message):
            r"""Prediction results for a Place Autocomplete prediction.

            Attributes:
                place (str):
                    The resource name of the suggested Place.
                    This name can be used in other APIs that accept
                    Place names.
                place_id (str):
                    The unique identifier of the suggested Place.
                    This identifier can be used in other APIs that
                    accept Place IDs.
                text (google.maps.places_v1.types.AutocompletePlacesResponse.Suggestion.FormattableText):
                    Contains the human-readable name for the returned result.
                    For establishment results, this is usually the business name
                    and address.

                    ``text`` is recommended for developers who wish to show a
                    single UI element. Developers who wish to show two separate,
                    but related, UI elements may want to use
                    ``structured_format`` instead. They are two different ways
                    to represent a Place prediction. Users should not try to
                    parse ``structured_format`` into ``text`` or vice versa.

                    This text may be different from the ``display_name``
                    returned by GetPlace.

                    May be in mixed languages if the request ``input`` and
                    ``language_code`` are in different languages or if the Place
                    does not have a translation from the local language to
                    ``language_code``.
                structured_format (google.maps.places_v1.types.AutocompletePlacesResponse.Suggestion.StructuredFormat):
                    A breakdown of the Place prediction into main text
                    containing the name of the Place and secondary text
                    containing additional disambiguating features (such as a
                    city or region).

                    ``structured_format`` is recommended for developers who wish
                    to show two separate, but related, UI elements. Developers
                    who wish to show a single UI element may want to use
                    ``text`` instead. They are two different ways to represent a
                    Place prediction. Users should not try to parse
                    ``structured_format`` into ``text`` or vice versa.
                types (MutableSequence[str]):
                    List of types that apply to this Place from
                    Table A or Table B in
                    https://developers.google.com/maps/documentation/places/web-service/place-types.

                    A type is a categorization of a Place. Places
                    with shared types will share similar
                    characteristics.
                distance_meters (int):
                    The length of the geodesic in meters from ``origin`` if
                    ``origin`` is specified. Certain predictions such as routes
                    may not populate this field.
            """

            place: str = proto.Field(
                proto.STRING,
                number=1,
            )
            place_id: str = proto.Field(
                proto.STRING,
                number=2,
            )
            text: "AutocompletePlacesResponse.Suggestion.FormattableText" = proto.Field(
                proto.MESSAGE,
                number=3,
                message="AutocompletePlacesResponse.Suggestion.FormattableText",
            )
            structured_format: "AutocompletePlacesResponse.Suggestion.StructuredFormat" = proto.Field(
                proto.MESSAGE,
                number=4,
                message="AutocompletePlacesResponse.Suggestion.StructuredFormat",
            )
            types: MutableSequence[str] = proto.RepeatedField(
                proto.STRING,
                number=5,
            )
            distance_meters: int = proto.Field(
                proto.INT32,
                number=6,
            )

        class QueryPrediction(proto.Message):
            r"""Prediction results for a Query Autocomplete prediction.

            Attributes:
                text (google.maps.places_v1.types.AutocompletePlacesResponse.Suggestion.FormattableText):
                    The predicted text. This text does not represent a Place,
                    but rather a text query that could be used in a search
                    endpoint (for example, Text Search).

                    ``text`` is recommended for developers who wish to show a
                    single UI element. Developers who wish to show two separate,
                    but related, UI elements may want to use
                    ``structured_format`` instead. They are two different ways
                    to represent a query prediction. Users should not try to
                    parse ``structured_format`` into ``text`` or vice versa.

                    May be in mixed languages if the request ``input`` and
                    ``language_code`` are in different languages or if part of
                    the query does not have a translation from the local
                    language to ``language_code``.
                structured_format (google.maps.places_v1.types.AutocompletePlacesResponse.Suggestion.StructuredFormat):
                    A breakdown of the query prediction into main text
                    containing the query and secondary text containing
                    additional disambiguating features (such as a city or
                    region).

                    ``structured_format`` is recommended for developers who wish
                    to show two separate, but related, UI elements. Developers
                    who wish to show a single UI element may want to use
                    ``text`` instead. They are two different ways to represent a
                    query prediction. Users should not try to parse
                    ``structured_format`` into ``text`` or vice versa.
            """

            text: "AutocompletePlacesResponse.Suggestion.FormattableText" = proto.Field(
                proto.MESSAGE,
                number=1,
                message="AutocompletePlacesResponse.Suggestion.FormattableText",
            )
            structured_format: "AutocompletePlacesResponse.Suggestion.StructuredFormat" = proto.Field(
                proto.MESSAGE,
                number=2,
                message="AutocompletePlacesResponse.Suggestion.StructuredFormat",
            )

        place_prediction: "AutocompletePlacesResponse.Suggestion.PlacePrediction" = (
            proto.Field(
                proto.MESSAGE,
                number=1,
                oneof="kind",
                message="AutocompletePlacesResponse.Suggestion.PlacePrediction",
            )
        )
        query_prediction: "AutocompletePlacesResponse.Suggestion.QueryPrediction" = (
            proto.Field(
                proto.MESSAGE,
                number=2,
                oneof="kind",
                message="AutocompletePlacesResponse.Suggestion.QueryPrediction",
            )
        )

    suggestions: MutableSequence[Suggestion] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=Suggestion,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
from google.type import money_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.maps.places.v1",
    manifest={
        "FuelOptions",
    },
)


class FuelOptions(proto.Message):
    r"""The most recent information about fuel options in a gas
    station. This information is updated regularly.

    Attributes:
        fuel_prices (MutableSequence[google.maps.places_v1.types.FuelOptions.FuelPrice]):
            The last known fuel price for each type of
            fuel this station has. There is one entry per
            fuel type this station has. Order is not
            important.
    """

    class FuelPrice(proto.Message):
        r"""Fuel price information for a given type.

        Attributes:
            type_ (google.maps.places_v1.types.FuelOptions.FuelPrice.FuelType):
                The type of fuel.
            price (google.type.money_pb2.Money):
                The price of the fuel.
            update_time (google.protobuf.timestamp_pb2.Timestamp):
                The time the fuel price was last updated.
        """

        class FuelType(proto.Enum):
            r"""Types of fuel.

            Values:
                FUEL_TYPE_UNSPECIFIED (0):
                    Unspecified fuel type.
                DIESEL (1):
                    Diesel fuel.
                DIESEL_PLUS (19):
                    Diesel plus fuel.
                REGULAR_UNLEADED (2):
                    Regular unleaded.
                MIDGRADE (3):
                    Midgrade.
                PREMIUM (4):
                    Premium.
                SP91 (5):
                    SP 91.
                SP91_E10 (6):
                    SP 91 E10.
                SP92 (7):
                    SP 92.
                SP95 (8):
                    SP 95.
                SP95_E10 (9):
                    SP95 E10.
                SP98 (10):
                    SP 98.
                SP99 (11):
                    SP 99.
                SP100 (12):
                    SP 100.
                LPG (13):
                    Liquefied Petroleum Gas.
                E80 (14):
                    E 80.
                E85 (15):
                    E 85.
                E100 (20):
                    E 100.
                METHANE (16):
                    Methane.
                BIO_DIESEL (17):
                    Bio-diesel.
                TRUCK_DIESEL (18):
                    Truck diesel.
            """
            FUEL_TYPE_UNSPECIFIED = 0
            DIESEL = 1
            DIESEL_PLUS = 19
            REGULAR_UNLEADED = 2
            MIDGRADE = 3
            PREMIUM = 4
            SP91 = 5
            SP91_E10 = 6
            SP92 = 7
            SP95 = 8
            SP95_E10 = 9
            SP98 = 10
            SP99 = 11
            SP100 = 12
            LPG = 13
            E80 = 14
            E85 = 15
            E100 = 20
            METHANE = 16
            BIO_DIESEL = 17
            TRUCK_DIESEL = 18

        type_: "FuelOptions.FuelPrice.FuelType" = proto.Field(
            proto.ENUM,
            number=1,
            enum="FuelOptions.FuelPrice.FuelType",
        )
        price: money_pb2.Money = proto.Field(
            proto.MESSAGE,
            number=2,
            message=money_pb2.Money,
        )
        update_time: timestamp_pb2.Timestamp = proto.Field(
            proto.MESSAGE,
            number=3,
            message=timestamp_pb2.Timestamp,
        )

    fuel_prices: MutableSequence[FuelPrice] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=FuelPrice,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.maps.places_v1.types import review

__protobuf__ = proto.module(
    package="google.maps.places.v1",
    manifest={
        "References",
    },
)


class References(proto.Message):
    r"""Experimental: See
    https://developers.google.com/maps/documentation/places/web-service/experimental/places-generative
    for more details.

    Reference that the generative content is related to.

    Attributes:
        reviews (MutableSequence[google.maps.places_v1.types.Review]):
            Reviews that serve as references.
        places (MutableSequence[str]):
            The list of resource names of the referenced
            places. This name can be used in other APIs that
            accept Place resource names.
    """

    reviews: MutableSequence[review.Review] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=review.Review,
    )
    places: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.geo.type.types import viewport as ggt_viewport
from google.protobuf import timestamp_pb2  # type: ignore
from google.type import date_pb2  # type: ignore
from google.type import datetime_pb2  # type: ignore
from google.type import latlng_pb2  # type: ignore
from google.type import localized_text_pb2  # type: ignore
from google.type import postal_address_pb2  # type: ignore
import proto  # type: ignore

from google.maps.places_v1.types import address_descriptor as gmp_address_descriptor
from google.maps.places_v1.types import content_block, ev_charging
from google.maps.places_v1.types import fuel_options as gmp_fuel_options
from google.maps.places_v1.types import photo
from google.maps.places_v1.types import price_range as gmp_price_range
from google.maps.places_v1.types import review

__protobuf__ = proto.module(
    package="google.maps.places.v1",
    manifest={
        "PriceLevel",
        "Place",
    },
)


class PriceLevel(proto.Enum):
    r"""Price level of the place.

    Values:
        PRICE_LEVEL_UNSPECIFIED (0):
            Place price level is unspecified or unknown.
        PRICE_LEVEL_FREE (1):
            Place provides free services.
        PRICE_LEVEL_INEXPENSIVE (2):
            Place provides inexpensive services.
        PRICE_LEVEL_MODERATE (3):
            Place provides moderately priced services.
        PRICE_LEVEL_EXPENSIVE (4):
            Place provides expensive services.
        PRICE_LEVEL_VERY_EXPENSIVE (5):
            Place provides very expensive services.
    """
    PRICE_LEVEL_UNSPECIFIED = 0
    PRICE_LEVEL_FREE = 1
    PRICE_LEVEL_INEXPENSIVE = 2
    PRICE_LEVEL_MODERATE = 3
    PRICE_LEVEL_EXPENSIVE = 4
    PRICE_LEVEL_VERY_EXPENSIVE = 5


class Place(proto.Message):
    r"""All the information representing a Place.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            This Place's resource name, in ``places/{place_id}`` format.
            Can be used to look up the Place.
        id (str):
            The unique identifier of a place.
        display_name (google.type.localized_text_pb2.LocalizedText):
            The localized name of the place, suitable as
            a short human-readable description. For example,
            "Google Sydney", "Starbucks", "Pyrmont", etc.
        types (MutableSequence[str]):
            A set of type tags for this result. For
            example, "political" and "locality". For the
            complete list of possible values, see Table A
            and Table B at
            https://developers.google.com/maps/documentation/places/web-service/place-types
        primary_type (str):
            The primary type of the given result. This
            type must one of the Places API supported types.
            For example, "restaurant", "cafe", "airport",
            etc.  A place can only have a single primary
            type.  For the complete list of possible values,
            see Table A and Table B at
            https://developers.google.com/maps/documentation/places/web-service/place-types
        primary_type_display_name (google.type.localized_text_pb2.LocalizedText):
            The display name of the primary type,
            localized to the request language if applicable.
            For the complete list of possible values, see
            Table A and Table B at
            https://developers.google.com/maps/documentation/places/web-service/place-types
        national_phone_number (str):
            A human-readable phone number for the place,
            in national format.
        international_phone_number (str):
            A human-readable phone number for the place,
            in international format.
        formatted_address (str):
            A full, human-readable address for this
            place.
        short_formatted_address (str):
            A short, human-readable address for this
            place.
        postal_address (google.type.postal_address_pb2.PostalAddress):
            The address in postal address format.
        address_components (MutableSequence[google.maps.places_v1.types.Place.AddressComponent]):
            Repeated components for each locality level. Note the
            following facts about the address_components[] array:

            -  The array of address components may contain more
               components than the formatted_address.
            -  The array does not necessarily include all the political
               entities that contain an address, apart from those
               included in the formatted_address. To retrieve all the
               political entities that contain a specific address, you
               should use reverse geocoding, passing the
               latitude/longitude of the address as a parameter to the
               request.
            -  The format of the response is not guaranteed to remain
               the same between requests. In particular, the number of
               address_components varies based on the address requested
               and can change over time for the same address. A
               component can change position in the array. The type of
               the component can change. A particular component may be
               missing in a later response.
        plus_code (google.maps.places_v1.types.Place.PlusCode):
            Plus code of the place location lat/long.
        location (google.type.latlng_pb2.LatLng):
            The position of this place.
        viewport (google.geo.type.types.Viewport):
            A viewport suitable for displaying the place
            on an average-sized map. This viewport should
            not be used as the physical boundary or the
            service area of the business.
        rating (float):
            A rating between 1.0 and 5.0, based on user
            reviews of this place.
        google_maps_uri (str):
            A URL providing more information about this
            place.
        website_uri (str):
            The authoritative website for this place,
            e.g. a business' homepage. Note that for places
            that are part of a chain (e.g. an IKEA store),
            this will usually be the website for the
            individual store, not the overall chain.
        reviews (MutableSequence[google.maps.places_v1.types.Review]):
            List of reviews about this place, sorted by
            relevance. A maximum of 5 reviews can be
            returned.
        regular_opening_hours (google.maps.places_v1.types.Place.OpeningHours):
            The regular hours of operation. Note that if a place is
            always open (24 hours), the ``close`` field will not be set.
            Clients can rely on always open (24 hours) being represented
            as an
            ```open`` <https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#Period>`__
            period containing
            ```day`` <https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#Point>`__
            with value ``0``,
            ```hour`` <https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#Point>`__
            with value ``0``, and
            ```minute`` <https://developers.google.com/maps/documentation/places/web-service/reference/rest/v1/places#Point>`__
            with value ``0``.
        utc_offset_minutes (int):
            Number of minutes this place's timezone is
            currently offset from UTC. This is expressed in
            minutes to support timezones that are offset by
            fractions of an hour, e.g. X hours and 15
            minutes.

            This field is a member of `oneof`_ ``_utc_offset_minutes``.
        time_zone (google.type.datetime_pb2.TimeZone):
            IANA Time Zone Database time zone. For example
            "America/New_York".
        photos (MutableSequence[google.maps.places_v1.types.Photo]):
            Information (including references) about
            photos of this place. A maximum of 10 photos can
            be returned.
        adr_format_address (str):
            The place's address in adr microformat:
            http://microformats.org/wiki/adr.
        business_status (google.maps.places_v1.types.Place.BusinessStatus):
            The business status for the place.
        price_level (google.maps.places_v1.types.PriceLevel):
            Price level of the place.
        attributions (MutableSequence[google.maps.places_v1.types.Place.Attribution]):
            A set of data provider that must be shown
            with this result.
        user_rating_count (int):
            The total number of reviews (with or without
            text) for this place.

            This field is a member of `oneof`_ ``_user_rating_count``.
        icon_mask_base_uri (str):
            A truncated URL to an icon mask. User can
            access different icon type by appending type
            suffix to the end (eg, ".svg" or ".png").
        icon_background_color (str):
            Background color for icon_mask in hex format, e.g. #909CE1.
        takeout (bool):
            Specifies if the business supports takeout.

            This field is a member of `oneof`_ ``_takeout``.
        delivery (bool):
            Specifies if the business supports delivery.

            This field is a member of `oneof`_ ``_delivery``.
        dine_in (bool):
            Specifies if the business supports indoor or
            outdoor seating options.

            This field is a member of `oneof`_ ``_dine_in``.
        curbside_pickup (bool):
            Specifies if the business supports curbside
            pickup.

            This field is a member of `oneof`_ ``_curbside_pickup``.
        reservable (bool):
            Specifies if the place supports reservations.

            This field is a member of `oneof`_ ``_reservable``.
        serves_breakfast (bool):
            Specifies if the place serves breakfast.

            This field is a member of `oneof`_ ``_serves_breakfast``.
        serves_lunch (bool):
            Specifies if the place serves lunch.

            This field is a member of `oneof`_ ``_serves_lunch``.
        serves_dinner (bool):
            Specifies if the place serves dinner.

            This field is a member of `oneof`_ ``_serves_dinner``.
        serves_beer (bool):
            Specifies if the place serves beer.

            This field is a member of `oneof`_ ``_serves_beer``.
        serves_wine (bool):
            Specifies if the place serves wine.

            This field is a member of `oneof`_ ``_serves_wine``.
        serves_brunch (bool):
            Specifies if the place serves brunch.

            This field is a member of `oneof`_ ``_serves_brunch``.
        serves_vegetarian_food (bool):
            Specifies if the place serves vegetarian
            food.

            This field is a member of `oneof`_ ``_serves_vegetarian_food``.
        current_opening_hours (google.maps.places_v1.types.Place.OpeningHours):
            The hours of operation for the next seven days (including
            today). The time period starts at midnight on the date of
            the request and ends at 11:59 pm six days later. This field
            includes the special_days subfield of all hours, set for
            dates that have exceptional hours.
        current_secondary_opening_hours (MutableSequence[google.maps.places_v1.types.Place.OpeningHours]):
            Contains an array of entries for the next seven days
            including information about secondary hours of a business.
            Secondary hours are different from a business's main hours.
            For example, a restaurant can specify drive through hours or
            delivery hours as its secondary hours. This field populates
            the type subfield, which draws from a predefined list of
            opening hours types (such as DRIVE_THROUGH, PICKUP, or
            TAKEOUT) based on the types of the place. This field
            includes the special_days subfield of all hours, set for
            dates that have exceptional hours.
        regular_secondary_opening_hours (MutableSequence[google.maps.places_v1.types.Place.OpeningHours]):
            Contains an array of entries for information about regular
            secondary hours of a business. Secondary hours are different
            from a business's main hours. For example, a restaurant can
            specify drive through hours or delivery hours as its
            secondary hours. This field populates the type subfield,
            which draws from a predefined list of opening hours types
            (such as DRIVE_THROUGH, PICKUP, or TAKEOUT) based on the
            types of the place.
        editorial_summary (google.type.localized_text_pb2.LocalizedText):
            Contains a summary of the place. A summary is
            comprised of a textual overview, and also
            includes the language code for these if
            applicable. Summary text must be presented as-is
            and can not be modified or altered.
        outdoor_seating (bool):
            Place provides outdoor seating.

            This field is a member of `oneof`_ ``_outdoor_seating``.
        live_music (bool):
            Place provides live music.

            This field is a member of `oneof`_ ``_live_music``.
        menu_for_children (bool):
            Place has a children's menu.

            This field is a member of `oneof`_ ``_menu_for_children``.
        serves_cocktails (bool):
            Place serves cocktails.

            This field is a member of `oneof`_ ``_serves_cocktails``.
        serves_dessert (bool):
            Place serves dessert.

            This field is a member of `oneof`_ ``_serves_dessert``.
        serves_coffee (bool):
            Place serves coffee.

            This field is a member of `oneof`_ ``_serves_coffee``.
        good_for_children (bool):
            Place is good for children.

            This field is a member of `oneof`_ ``_good_for_children``.
        allows_dogs (bool):
            Place allows dogs.

            This field is a member of `oneof`_ ``_allows_dogs``.
        restroom (bool):
            Place has restroom.

            This field is a member of `oneof`_ ``_restroom``.
        good_for_groups (bool):
            Place accommodates groups.

            This field is a member of `oneof`_ ``_good_for_groups``.
        good_for_watching_sports (bool):
            Place is suitable for watching sports.

            This field is a member of `oneof`_ ``_good_for_watching_sports``.
        payment_options (google.maps.places_v1.types.Place.PaymentOptions):
            Payment options the place accepts. If a
            payment option data is not available, the
            payment option field will be unset.
        parking_options (google.maps.places_v1.types.Place.ParkingOptions):
            Options of parking provided by the place.
        sub_destinations (MutableSequence[google.maps.places_v1.types.Place.SubDestination]):
            A list of sub-destinations related to the
            place.
        accessibility_options (google.maps.places_v1.types.Place.AccessibilityOptions):
            Information about the accessibility options a
            place offers.

            This field is a member of `oneof`_ ``_accessibility_options``.
        fuel_options (google.maps.places_v1.types.FuelOptions):
            The most recent information about fuel
            options in a gas station. This information is
            updated regularly.
        ev_charge_options (google.maps.places_v1.types.EVChargeOptions):
            Information of ev charging options.
        generative_summary (google.maps.places_v1.types.Place.GenerativeSummary):
            AI-generated summary of the place.
        containing_places (MutableSequence[google.maps.places_v1.types.Place.ContainingPlace]):
            List of places in which the current place is
            located.
        pure_service_area_business (bool):
            Indicates whether the place is a pure service
            area business. Pure service area business is a
            business that visits or delivers to customers
            directly but does not serve customers at their
            business address. For example, businesses like
            cleaning services or plumbers. Those businesses
            may not have a physical address or location on
            Google Maps.

            This field is a member of `oneof`_ ``_pure_service_area_business``.
        address_descriptor (google.maps.places_v1.types.AddressDescriptor):
            The address descriptor of the place. Address
            descriptors include additional information that
            help describe a location using landmarks and
            areas. See address descriptor regional coverage
            in
            https://developers.google.com/maps/documentation/geocoding/address-descriptors/coverage.
        price_range (google.maps.places_v1.types.PriceRange):
            The price range associated with a Place.
        review_summary (google.maps.places_v1.types.Place.ReviewSummary):
            AI-generated summary of the place using user
            reviews.
        ev_charge_amenity_summary (google.maps.places_v1.types.Place.EvChargeAmenitySummary):
            The summary of amenities near the EV charging
            station.
        neighborhood_summary (google.maps.places_v1.types.Place.NeighborhoodSummary):
            A summary of points of interest near the
            place.
    """

    class BusinessStatus(proto.Enum):
        r"""Business status for the place.

        Values:
            BUSINESS_STATUS_UNSPECIFIED (0):
                Default value. This value is unused.
            OPERATIONAL (1):
                The establishment is operational, not
                necessarily open now.
            CLOSED_TEMPORARILY (2):
                The establishment is temporarily closed.
            CLOSED_PERMANENTLY (3):
                The establishment is permanently closed.
        """
        BUSINESS_STATUS_UNSPECIFIED = 0
        OPERATIONAL = 1
        CLOSED_TEMPORARILY = 2
        CLOSED_PERMANENTLY = 3

    class AddressComponent(proto.Message):
        r"""The structured components that form the formatted address, if
        this information is available.

        Attributes:
            long_text (str):
                The full text description or name of the address component.
                For example, an address component for the country Australia
                may have a long_name of "Australia".
            short_text (str):
                An abbreviated textual name for the address component, if
                available. For example, an address component for the country
                of Australia may have a short_name of "AU".
            types (MutableSequence[str]):
                An array indicating the type(s) of the
                address component.
            language_code (str):
                The language used to format this components,
                in CLDR notation.
        """

        long_text: str = proto.Field(
            proto.STRING,
            number=1,
        )
        short_text: str = proto.Field(
            proto.STRING,
            number=2,
        )
        types: MutableSequence[str] = proto.RepeatedField(
            proto.STRING,
            number=3,
        )
        language_code: str = proto.Field(
            proto.STRING,
            number=4,
        )

    class PlusCode(proto.Message):
        r"""Plus code (http://plus.codes) is a location reference with
        two formats: global code defining a 14mx14m (1/8000th of a
        degree) or smaller rectangle, and compound code, replacing the
        prefix with a reference location.

        Attributes:
            global_code (str):
                Place's global (full) code, such as
                "9FWM33GV+HQ", representing an 1/8000 by 1/8000
                degree area (~14 by 14 meters).
            compound_code (str):
                Place's compound code, such as "33GV+HQ,
                Ramberg, Norway", containing the suffix of the
                global code and replacing the prefix with a
                formatted name of a reference entity.
        """

        global_code: str = proto.Field(
            proto.STRING,
            number=1,
        )
        compound_code: str = proto.Field(
            proto.STRING,
            number=2,
        )

    class OpeningHours(proto.Message):
        r"""Information about business hour of the place.

        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            open_now (bool):
                Whether the opening hours period is currently
                active. For regular opening hours and current
                opening hours, this field means whether the
                place is open. For secondary opening hours and
                current secondary opening hours, this field
                means whether the secondary hours of this place
                is active.

                This field is a member of `oneof`_ ``_open_now``.
            periods (MutableSequence[google.maps.places_v1.types.Place.OpeningHours.Period]):
                The periods that this place is open during
                the week. The periods are in chronological
                order, starting with Sunday in the place-local
                timezone. An empty (but not absent) value
                indicates a place that is never open, e.g.
                because it is closed temporarily for
                renovations.
            weekday_descriptions (MutableSequence[str]):
                Localized strings describing the opening
                hours of this place, one string for each day of
                the week.  Will be empty if the hours are
                unknown or could not be converted to localized
                text. Example: "Sun: 18:00–06:00".
            secondary_hours_type (google.maps.places_v1.types.Place.OpeningHours.SecondaryHoursType):
                A type string used to identify the type of
                secondary hours.
            special_days (MutableSequence[google.maps.places_v1.types.Place.OpeningHours.SpecialDay]):
                Structured information for special days that fall within the
                period that the returned opening hours cover. Special days
                are days that could impact the business hours of a place,
                e.g. Christmas day. Set for current_opening_hours and
                current_secondary_opening_hours if there are exceptional
                hours.
            next_open_time (google.protobuf.timestamp_pb2.Timestamp):
                The next time the current opening hours
                period starts up to 7 days in the future. This
                field is only populated if the opening hours
                period is not active at the time of serving the
                request.
            next_close_time (google.protobuf.timestamp_pb2.Timestamp):
                The next time the current opening hours
                period ends up to 7 days in the future. This
                field is only populated if the opening hours
                period is active at the time of serving the
                request.
        """

        class SecondaryHoursType(proto.Enum):
            r"""A type used to identify the type of secondary hours.

            Values:
                SECONDARY_HOURS_TYPE_UNSPECIFIED (0):
                    Default value when secondary hour type is not
                    specified.
                DRIVE_THROUGH (1):
                    The drive-through hour for banks,
                    restaurants, or pharmacies.
                HAPPY_HOUR (2):
                    The happy hour.
                DELIVERY (3):
                    The delivery hour.
                TAKEOUT (4):
                    The takeout hour.
                KITCHEN (5):
                    The kitchen hour.
                BREAKFAST (6):
                    The breakfast hour.
                LUNCH (7):
                    The lunch hour.
                DINNER (8):
                    The dinner hour.
                BRUNCH (9):
                    The brunch hour.
                PICKUP (10):
                    The pickup hour.
                ACCESS (11):
                    The access hours for storage places.
                SENIOR_HOURS (12):
                    The special hours for seniors.
                ONLINE_SERVICE_HOURS (13):
                    The online service hours.
            """
            SECONDARY_HOURS_TYPE_UNSPECIFIED = 0
            DRIVE_THROUGH = 1
            HAPPY_HOUR = 2
            DELIVERY = 3
            TAKEOUT = 4
            KITCHEN = 5
            BREAKFAST = 6
            LUNCH = 7
            DINNER = 8
            BRUNCH = 9
            PICKUP = 10
            ACCESS = 11
            SENIOR_HOURS = 12
            ONLINE_SERVICE_HOURS = 13

        class Period(proto.Message):
            r"""A period the place remains in open_now status.

            Attributes:
                open_ (google.maps.places_v1.types.Place.OpeningHours.Period.Point):
                    The time that the place starts to be open.
                close (google.maps.places_v1.types.Place.OpeningHours.Period.Point):
                    The time that the place starts to be closed.
            """

            class Point(proto.Message):
                r"""Status changing points.

                .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

                Attributes:
                    day (int):
                        A day of the week, as an integer in the range
                        0-6.  0 is Sunday, 1 is Monday, etc.

                        This field is a member of `oneof`_ ``_day``.
                    hour (int):
                        The hour in 24 hour format. Ranges from 0 to
                        23.

                        This field is a member of `oneof`_ ``_hour``.
                    minute (int):
                        The minute. Ranges from 0 to 59.

                        This field is a member of `oneof`_ ``_minute``.
                    date (google.type.date_pb2.Date):
                        Date in the local timezone for the place.
                    truncated (bool):
                        Whether or not this endpoint was truncated. Truncation
                        occurs when the real hours are outside the times we are
                        willing to return hours between, so we truncate the hours
                        back to these boundaries. This ensures that at most 24 \* 7
                        hours from midnight of the day of the request are returned.
                """

                day: int = proto.Field(
                    proto.INT32,
                    number=1,
                    optional=True,
                )
                hour: int = proto.Field(
                    proto.INT32,
                    number=2,
                    optional=True,
                )
                minute: int = proto.Field(
                    proto.INT32,
                    number=3,
                    optional=True,
                )
                date: date_pb2.Date = proto.Field(
                    proto.MESSAGE,
                    number=6,
                    message=date_pb2.Date,
                )
                truncated: bool = proto.Field(
                    proto.BOOL,
                    number=5,
                )

            open_: "Place.OpeningHours.Period.Point" = proto.Field(
                proto.MESSAGE,
                number=1,
                message="Place.OpeningHours.Period.Point",
            )
            close: "Place.OpeningHours.Period.Point" = proto.Field(
                proto.MESSAGE,
                number=2,
                message="Place.OpeningHours.Period.Point",
            )

        class SpecialDay(proto.Message):
            r"""Structured information for special days that fall within the
            period that the returned opening hours cover. Special days are
            days that could impact the business hours of a place, e.g.
            Christmas day.

            Attributes:
                date (google.type.date_pb2.Date):
                    The date of this special day.
            """

            date: date_pb2.Date = proto.Field(
                proto.MESSAGE,
                number=1,
                message=date_pb2.Date,
            )

        open_now: bool = proto.Field(
            proto.BOOL,
            number=1,
            optional=True,
        )
        periods: MutableSequence["Place.OpeningHours.Period"] = proto.RepeatedField(
            proto.MESSAGE,
            number=2,
            message="Place.OpeningHours.Period",
        )
        weekday_descriptions: MutableSequence[str] = proto.RepeatedField(
            proto.STRING,
            number=3,
        )
        secondary_hours_type: "Place.OpeningHours.SecondaryHoursType" = proto.Field(
            proto.ENUM,
            number=4,
            enum="Place.OpeningHours.SecondaryHoursType",
        )
        special_days: MutableSequence[
            "Place.OpeningHours.SpecialDay"
        ] = proto.RepeatedField(
            proto.MESSAGE,
            number=5,
            message="Place.OpeningHours.SpecialDay",
        )
        next_open_time: timestamp_pb2.Timestamp = proto.Field(
            proto.MESSAGE,
            number=6,
            message=timestamp_pb2.Timestamp,
        )
        next_close_time: timestamp_pb2.Timestamp = proto.Field(
            proto.MESSAGE,
            number=7,
            message=timestamp_pb2.Timestamp,
        )

    class Attribution(proto.Message):
        r"""Information about data providers of this place.

        Attributes:
            provider (str):
                Name of the Place's data provider.
            provider_uri (str):
                URI to the Place's data provider.
        """

        provider: str = proto.Field(
            proto.STRING,
            number=1,
        )
        provider_uri: str = proto.Field(
            proto.STRING,
            number=2,
        )

    class PaymentOptions(proto.Message):
        r"""Payment options the place accepts.

        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            accepts_credit_cards (bool):
                Place accepts credit cards as payment.

                This field is a member of `oneof`_ ``_accepts_credit_cards``.
            accepts_debit_cards (bool):
                Place accepts debit cards as payment.

                This field is a member of `oneof`_ ``_accepts_debit_cards``.
            accepts_cash_only (bool):
                Place accepts cash only as payment. Places
                with this attribute may still accept other
                payment methods.

                This field is a member of `oneof`_ ``_accepts_cash_only``.
            accepts_nfc (bool):
                Place accepts NFC payments.

                This field is a member of `oneof`_ ``_accepts_nfc``.
        """

        accepts_credit_cards: bool = proto.Field(
            proto.BOOL,
            number=1,
            optional=True,
        )
        accepts_debit_cards: bool = proto.Field(
            proto.BOOL,
            number=2,
            optional=True,
        )
        accepts_cash_only: bool = proto.Field(
            proto.BOOL,
            number=3,
            optional=True,
        )
        accepts_nfc: bool = proto.Field(
            proto.BOOL,
            number=4,
            optional=True,
        )

    class ParkingOptions(proto.Message):
        r"""Information about parking options for the place. A parking
        lot could support more than one option at the same time.


        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            free_parking_lot (bool):
                Place offers free parking lots.

                This field is a member of `oneof`_ ``_free_parking_lot``.
            paid_parking_lot (bool):
                Place offers paid parking lots.

                This field is a member of `oneof`_ ``_paid_parking_lot``.
            free_street_parking (bool):
                Place offers free street parking.

                This field is a member of `oneof`_ ``_free_street_parking``.
            paid_street_parking (bool):
                Place offers paid street parking.

                This field is a member of `oneof`_ ``_paid_street_parking``.
            valet_parking (bool):
                Place offers valet parking.

                This field is a member of `oneof`_ ``_valet_parking``.
            free_garage_parking (bool):
                Place offers free garage parking.

                This field is a member of `oneof`_ ``_free_garage_parking``.
            paid_garage_parking (bool):
                Place offers paid garage parking.

                This field is a member of `oneof`_ ``_paid_garage_parking``.
        """

        free_parking_lot: bool = proto.Field(
            proto.BOOL,
            number=1,
            optional=True,
        )
        paid_parking_lot: bool = proto.Field(
            proto.BOOL,
            number=2,
            optional=True,
        )
        free_street_parking: bool = proto.Field(
            proto.BOOL,
            number=3,
            optional=True,
        )
        paid_street_parking: bool = proto.Field(
            proto.BOOL,
            number=4,
            optional=True,
        )
        valet_parking: bool = proto.Field(
            proto.BOOL,
            number=5,
            optional=True,
        )
        free_garage_parking: bool = proto.Field(
            proto.BOOL,
            number=6,
            optional=True,
        )
        paid_garage_parking: bool = proto.Field(
            proto.BOOL,
            number=7,
            optional=True,
        )

    class SubDestination(proto.Message):
        r"""Sub-destinations are specific places associated with a main
        place. These provide more specific destinations for users who
        are searching within a large or complex place, like an airport,
        national park, university, or stadium. For example,
        sub-destinations at an airport might include associated
        terminals and parking lots. Sub-destinations return the place ID
        and place resource name, which can be used in subsequent Place
        Details (New) requests to fetch richer details, including the
        sub-destination's display name and location.

        Attributes:
            name (str):
                The resource name of the sub-destination.
            id (str):
                The place id of the sub-destination.
        """

        name: str = proto.Field(
            proto.STRING,
            number=1,
        )
        id: str = proto.Field(
            proto.STRING,
            number=2,
        )

    class AccessibilityOptions(proto.Message):
        r"""Information about the accessibility options a place offers.

        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            wheelchair_accessible_parking (bool):
                Place offers wheelchair accessible parking.

                This field is a member of `oneof`_ ``_wheelchair_accessible_parking``.
            wheelchair_accessible_entrance (bool):
                Places has wheelchair accessible entrance.

                This field is a member of `oneof`_ ``_wheelchair_accessible_entrance``.
            wheelchair_accessible_restroom (bool):
                Place has wheelchair accessible restroom.

                This field is a member of `oneof`_ ``_wheelchair_accessible_restroom``.
            wheelchair_accessible_seating (bool):
                Place has wheelchair accessible seating.

                This field is a member of `oneof`_ ``_wheelchair_accessible_seating``.
        """

        wheelchair_accessible_parking: bool = proto.Field(
            proto.BOOL,
            number=1,
            optional=True,
        )
        wheelchair_accessible_entrance: bool = proto.Field(
            proto.BOOL,
            number=2,
            optional=True,
        )
        wheelchair_accessible_restroom: bool = proto.Field(
            proto.BOOL,
            number=3,
            optional=True,
        )
        wheelchair_accessible_seating: bool = proto.Field(
            proto.BOOL,
            number=4,
            optional=True,
        )

    class GenerativeSummary(proto.Message):
        r"""AI-generated summary of the place.

        Attributes:
            overview (google.type.localized_text_pb2.LocalizedText):
                The overview of the place.
            overview_flag_content_uri (str):
                A link where users can flag a problem with
                the overview summary.
            disclosure_text (google.type.localized_text_pb2.LocalizedText):
                The AI disclosure message "Summarized with
                Gemini" (and its localized variants). This will
                be in the language specified in the request if
                available.
        """

        overview: localized_text_pb2.LocalizedText = proto.Field(
            proto.MESSAGE,
            number=1,
            message=localized_text_pb2.LocalizedText,
        )
        overview_flag_content_uri: str = proto.Field(
            proto.STRING,
            number=4,
        )
        disclosure_text: localized_text_pb2.LocalizedText = proto.Field(
            proto.MESSAGE,
            number=6,
            message=localized_text_pb2.LocalizedText,
        )

    class ContainingPlace(proto.Message):
        r"""Info about the place in which this place is located.

        Attributes:
            name (str):
                The resource name of the place in which this
                place is located.
            id (str):
                The place id of the place in which this place
                is located.
        """

        name: str = proto.Field(
            proto.STRING,
            number=1,
        )
        id: str = proto.Field(
            proto.STRING,
            number=2,
        )

    class ReviewSummary(proto.Message):
        r"""AI-generated summary of the place using user reviews.

        Attributes:
            text (google.type.localized_text_pb2.LocalizedText):
                The summary of user reviews.
            flag_content_uri (str):
                A link where users can flag a problem with
                the summary.
            disclosure_text (google.type.localized_text_pb2.LocalizedText):
                The AI disclosure message "Summarized with
                Gemini" (and its localized variants). This will
                be in the language specified in the request if
                available.
        """

        text: localized_text_pb2.LocalizedText = proto.Field(
            proto.MESSAGE,
            number=1,
            message=localized_text_pb2.LocalizedText,
        )
        flag_content_uri: str = proto.Field(
            proto.STRING,
            number=2,
        )
        disclosure_text: localized_text_pb2.LocalizedText = proto.Field(
            proto.MESSAGE,
            number=3,
            message=localized_text_pb2.LocalizedText,
        )

    class EvChargeAmenitySummary(proto.Message):
        r"""The summary of amenities near the EV charging station. This only
        applies to places with type ``electric_vehicle_charging_station``.
        The ``overview`` field is guaranteed to be provided while the other
        fields are optional.

        Attributes:
            overview (google.maps.places_v1.types.ContentBlock):
                An overview of the available amenities. This
                is guaranteed to be provided.
            coffee (google.maps.places_v1.types.ContentBlock):
                A summary of the nearby coffee options.
            restaurant (google.maps.places_v1.types.ContentBlock):
                A summary of the nearby restaurants.
            store (google.maps.places_v1.types.ContentBlock):
                A summary of the nearby gas stations.
            flag_content_uri (str):
                A link where users can flag a problem with
                the summary.
            disclosure_text (google.type.localized_text_pb2.LocalizedText):
                The AI disclosure message "Summarized with
                Gemini" (and its localized variants). This will
                be in the language specified in the request if
                available.
        """

        overview: content_block.ContentBlock = proto.Field(
            proto.MESSAGE,
            number=1,
            message=content_block.ContentBlock,
        )
        coffee: content_block.ContentBlock = proto.Field(
            proto.MESSAGE,
            number=2,
            message=content_block.ContentBlock,
        )
        restaurant: content_block.ContentBlock = proto.Field(
            proto.MESSAGE,
            number=3,
            message=content_block.ContentBlock,
        )
        store: content_block.ContentBlock = proto.Field(
            proto.MESSAGE,
            number=4,
            message=content_block.ContentBlock,
        )
        flag_content_uri: str = proto.Field(
            proto.STRING,
            number=5,
        )
        disclosure_text: localized_text_pb2.LocalizedText = proto.Field(
            proto.MESSAGE,
            number=6,
            message=localized_text_pb2.LocalizedText,
        )

    class NeighborhoodSummary(proto.Message):
        r"""A summary of points of interest near the place.

        Attributes:
            overview (google.maps.places_v1.types.ContentBlock):
                An overview summary of the neighborhood.
            description (google.maps.places_v1.types.ContentBlock):
                A detailed description of the neighborhood.
            flag_content_uri (str):
                A link where users can flag a problem with
                the summary.
            disclosure_text (google.type.localized_text_pb2.LocalizedText):
                The AI disclosure message "Summarized with
                Gemini" (and its localized variants). This will
                be in the language specified in the request if
                available.
        """

        overview: content_block.ContentBlock = proto.Field(
            proto.MESSAGE,
            number=1,
            message=content_block.ContentBlock,
        )
        description: content_block.ContentBlock = proto.Field(
            proto.MESSAGE,
            number=2,
            message=content_block.ContentBlock,
        )
        flag_content_uri: str = proto.Field(
            proto.STRING,
            number=3,
        )
        disclosure_text: localized_text_pb2.LocalizedText = proto.Field(
            proto.MESSAGE,
            number=4,
            message=localized_text_pb2.LocalizedText,
        )

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    display_name: localized_text_pb2.LocalizedText = proto.Field(
        proto.MESSAGE,
        number=31,
        message=localized_text_pb2.LocalizedText,
    )
    types: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=5,
    )
    primary_type: str = proto.Field(
        proto.STRING,
        number=50,
    )
    primary_type_display_name: localized_text_pb2.LocalizedText = proto.Field(
        proto.MESSAGE,
        number=32,
        message=localized_text_pb2.LocalizedText,
    )
    national_phone_number: str = proto.Field(
        proto.STRING,
        number=7,
    )
    international_phone_number: str = proto.Field(
        proto.STRING,
        number=8,
    )
    formatted_address: str = proto.Field(
        proto.STRING,
        number=9,
    )
    short_formatted_address: str = proto.Field(
        proto.STRING,
        number=51,
    )
    postal_address: postal_address_pb2.PostalAddress = proto.Field(
        proto.MESSAGE,
        number=90,
        message=postal_address_pb2.PostalAddress,
    )
    address_components: MutableSequence[AddressComponent] = proto.RepeatedField(
        proto.MESSAGE,
        number=10,
        message=AddressComponent,
    )
    plus_code: PlusCode = proto.Field(
        proto.MESSAGE,
        number=11,
        message=PlusCode,
    )
    location: latlng_pb2.LatLng = proto.Field(
        proto.MESSAGE,
        number=12,
        message=latlng_pb2.LatLng,
    )
    viewport: ggt_viewport.Viewport = proto.Field(
        proto.MESSAGE,
        number=13,
        message=ggt_viewport.Viewport,
    )
    rating: float = proto.Field(
        proto.DOUBLE,
        number=14,
    )
    google_maps_uri: str = proto.Field(
        proto.STRING,
        number=15,
    )
    website_uri: str = proto.Field(
        proto.STRING,
        number=16,
    )
    reviews: MutableSequence[review.Review] = proto.RepeatedField(
        proto.MESSAGE,
        number=53,
        message=review.Review,
    )
    regular_opening_hours: OpeningHours = proto.Field(
        proto.MESSAGE,
        number=21,
        message=OpeningHours,
    )
    utc_offset_minutes: int = proto.Field(
        proto.INT32,
        number=22,
        optional=True,
    )
    time_zone: datetime_pb2.TimeZone = proto.Field(
        proto.MESSAGE,
        number=88,
        message=datetime_pb2.TimeZone,
    )
    photos: MutableSequence[photo.Photo] = proto.RepeatedField(
        proto.MESSAGE,
        number=54,
        message=photo.Photo,
    )
    adr_format_address: str = proto.Field(
        proto.STRING,
        number=24,
    )
    business_status: BusinessStatus = proto.Field(
        proto.ENUM,
        number=25,
        enum=BusinessStatus,
    )
    price_level: "PriceLevel" = proto.Field(
        proto.ENUM,
        number=26,
        enum="PriceLevel",
    )
    attributions: MutableSequence[Attribution] = proto.RepeatedField(
        proto.MESSAGE,
        number=27,
        message=Attribution,
    )
    user_rating_count: int = proto.Field(
        proto.INT32,
        number=28,
        optional=True,
    )
    icon_mask_base_uri: str = proto.Field(
        proto.STRING,
        number=29,
    )
    icon_background_color: str = proto.Field(
        proto.STRING,
        number=30,
    )
    takeout: bool = proto.Field(
        proto.BOOL,
        number=33,
        optional=True,
    )
    delivery: bool = proto.Field(
        proto.BOOL,
        number=34,
        optional=True,
    )
    dine_in: bool = proto.Field(
        proto.BOOL,
        number=35,
        optional=True,
    )
    curbside_pickup: bool = proto.Field(
        proto.BOOL,
        number=36,
        optional=True,
    )
    reservable: bool = proto.Field(
        proto.BOOL,
        number=38,
        optional=True,
    )
    serves_breakfast: bool = proto.Field(
        proto.BOOL,
        number=39,
        optional=True,
    )
    serves_lunch: bool = proto.Field(
        proto.BOOL,
        number=40,
        optional=True,
    )
    serves_dinner: bool = proto.Field(
        proto.BOOL,
        number=41,
        optional=True,
    )
    serves_beer: bool = proto.Field(
        proto.BOOL,
        number=42,
        optional=True,
    )
    serves_wine: bool = proto.Field(
        proto.BOOL,
        number=43,
        optional=True,
    )
    serves_brunch: bool = proto.Field(
        proto.BOOL,
        number=44,
        optional=True,
    )
    serves_vegetarian_food: bool = proto.Field(
        proto.BOOL,
        number=45,
        optional=True,
    )
    current_opening_hours: OpeningHours = proto.Field(
        proto.MESSAGE,
        number=46,
        message=OpeningHours,
    )
    current_secondary_opening_hours: MutableSequence[
        OpeningHours
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=47,
        message=OpeningHours,
    )
    regular_secondary_opening_hours: MutableSequence[
        OpeningHours
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=49,
        message=OpeningHours,
    )
    editorial_summary: localized_text_pb2.LocalizedText = proto.Field(
        proto.MESSAGE,
        number=52,
        message=localized_text_pb2.LocalizedText,
    )
    outdoor_seating: bool = proto.Field(
        proto.BOOL,
        number=55,
        optional=True,
    )
    live_music: bool = proto.Field(
        proto.BOOL,
        number=56,
        optional=True,
    )
    menu_for_children: bool = proto.Field(
        proto.BOOL,
        number=57,
        optional=True,
    )
    serves_cocktails: bool = proto.Field(
        proto.BOOL,
        number=58,
        optional=True,
    )
    serves_dessert: bool = proto.Field(
        proto.BOOL,
        number=59,
        optional=True,
    )
    serves_coffee: bool = proto.Field(
        proto.BOOL,
        number=60,
        optional=True,
    )
    good_for_children: bool = proto.Field(
        proto.BOOL,
        number=62,
        optional=True,
    )
    allows_dogs: bool = proto.Field(
        proto.BOOL,
        number=63,
        optional=True,
    )
    restroom: bool = proto.Field(
        proto.BOOL,
        number=64,
        optional=True,
    )
    good_for_groups: bool = proto.Field(
        proto.BOOL,
        number=65,
        optional=True,
    )
    good_for_watching_sports: bool = proto.Field(
        proto.BOOL,
        number=66,
        optional=True,
    )
    payment_options: PaymentOptions = proto.Field(
        proto.MESSAGE,
        number=67,
        message=PaymentOptions,
    )
    parking_options: ParkingOptions = proto.Field(
        proto.MESSAGE,
        number=70,
        message=ParkingOptions,
    )
    sub_destinations: MutableSequence[SubDestination] = proto.RepeatedField(
        proto.MESSAGE,
        number=71,
        message=SubDestination,
    )
    accessibility_options: AccessibilityOptions = proto.Field(
        proto.MESSAGE,
        number=72,
        optional=True,
        message=AccessibilityOptions,
    )
    fuel_options: gmp_fuel_options.FuelOptions = proto.Field(
        proto.MESSAGE,
        number=78,
        message=gmp_fuel_options.FuelOptions,
    )
    ev_charge_options: ev_charging.EVChargeOptions = proto.Field(
        proto.MESSAGE,
        number=79,
        message=ev_charging.EVChargeOptions,
    )
    generative_summary: GenerativeSummary = proto.Field(
        proto.MESSAGE,
        number=80,
        message=GenerativeSummary,
    )
    containing_places: MutableSequence[ContainingPlace] = proto.RepeatedField(
        proto.MESSAGE,
        number=82,
        message=ContainingPlace,
    )
    pure_service_area_business: bool = proto.Field(
        proto.BOOL,
        number=83,
        optional=True,
    )
    address_descriptor: gmp_address_descriptor.AddressDescriptor = proto.Field(
        proto.MESSAGE,
        number=84,
        message=gmp_address_descriptor.AddressDescriptor,
    )
    price_range: gmp_price_range.PriceRange = proto.Field(
        proto.MESSAGE,
        number=86,
        message=gmp_price_range.PriceRange,
    )
    review_summary: ReviewSummary = proto.Field(
        proto.MESSAGE,
        number=87,
        message=ReviewSummary,
    )
    ev_charge_amenity_summary: EvChargeAmenitySummary = proto.Field(
        proto.MESSAGE,
        number=89,
        message=EvChargeAmenitySummary,
    )
    neighborhood_summary: NeighborhoodSummary = proto.Field(
        proto.MESSAGE,
        number=91,
        message=NeighborhoodSummary,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
